@@ -1,45 +1,49 @@
 # -*- coding: utf-8 -*-
 """
-:mod:`orion.client.experiment` -- Experiment wrapper client
-===========================================================
-
-.. module:: experiment
-   :platform: Unix
-   :synopsis: Wraps the core Experiment object to provide further functionalities for the user
+Experiment wrapper client
+=========================
 
+Wraps the core Experiment object to provide further functionalities for the user
 """
 import atexit
 import functools
+import inspect
 import logging
 import sys
 
 from numpy import inf as infinity
 
-from orion.core.io.database import DuplicateKeyError
-from orion.core.utils.exceptions import BrokenExperiment, SampleTimeout, WaitingForTrials
-from orion.core.utils.flatten import flatten, unflatten
 import orion.core.utils.format_trials as format_trials
 import orion.core.worker
+from orion.core.io.database import DuplicateKeyError
+from orion.core.utils.exceptions import (
+    BrokenExperiment,
+    SampleTimeout,
+    UnsupportedOperation,
+    WaitingForTrials,
+)
+from orion.core.utils.flatten import flatten, unflatten
 from orion.core.worker.trial import Trial
 from orion.core.worker.trial_pacemaker import TrialPacemaker
 from orion.plotting.base import PlotAccessor
 from orion.storage.base import FailedUpdate
 
-
 log = logging.getLogger(__name__)
 
 
 def set_broken_trials(client):
     """Release all trials with status broken if the process exits without releasing them."""
     if sys.exc_info()[0] is KeyboardInterrupt:
-        status = 'interrupted'
+        status = "interrupted"
     else:
-        status = 'broken'
+        status = "broken"
 
     for trial_id in list(client._pacemakers.keys()):  # pylint: disable=protected-access
         trial = client.get_trial(uid=trial_id)
         if trial is None:
-            log.warning('Trial {} was not found in storage, could not set status to `broken`.')
+            log.warning(
+                "Trial {} was not found in storage, could not set status to `broken`."
+            )
             continue
         client.release(trial, status=status)
 
@@ -116,6 +120,11 @@ class ExperimentClient:
         """Algorithms of the experiment."""
         return self._experiment.algorithms
 
+    @property
+    def refers(self):
+        """References to the experiment version control"""
+        return self._experiment.refers
+
     @property
     def is_done(self):
         """Return True, if this experiment is considered to be finished.
@@ -152,8 +161,8 @@ class ExperimentClient:
         trials_completed : int
            Number of completed trials
         best_trials_id : int
-           Unique identifier of the `Trial` object in the database which achieved
-           the best known objective result.
+           Unique identifier of the :class:`orion.core.worker.trial.Trial` object in the database
+           which achieved the best known objective result.
         best_evaluation : float
            Evaluation score of the best trial
         start_time : `datetime.datetime`
@@ -181,6 +190,32 @@ class ExperimentClient:
         """Return the producer configuration of the experiment."""
         return self._experiment.producer
 
+    @property
+    def mode(self):
+        """Return the access right of the experiment
+
+        {'r': read, 'w': read/write, 'x': read/write/execute}
+        """
+        return self._experiment.mode
+
+    ###
+    # Rights
+    ###
+
+    def _check_if_writable(self):
+        if self.mode == "r":
+            calling_function = inspect.stack()[1].function
+            raise UnsupportedOperation(
+                f"ExperimentClient must have write rights to execute `{calling_function}()`"
+            )
+
+    def _check_if_executable(self):
+        if self.mode != "x":
+            calling_function = inspect.stack()[1].function
+            raise UnsupportedOperation(
+                f"ExperimentClient must have execution rights to execute `{calling_function}()`"
+            )
+
     ###
     # Queries
     ###
@@ -238,23 +273,25 @@ class ExperimentClient:
     def fetch_trials_by_status(self, status, with_evc_tree=False):
         """Fetch all trials with the given status
 
-        Trials are sorted based on `Trial.submit_time`
+        Trials are sorted based on ``Trial.submit_time``
 
-        :return: list of `Trial` objects
+        :return: list of :class:`orion.core.worker.trial.Trial` objects
         """
-        return self._experiment.fetch_trials_by_status(status, with_evc_tree=with_evc_tree)
+        return self._experiment.fetch_trials_by_status(
+            status, with_evc_tree=with_evc_tree
+        )
 
     def fetch_noncompleted_trials(self, with_evc_tree=False):
         """Fetch non-completed trials of this `Experiment` instance.
 
-        Trials are sorted based on `Trial.submit_time`
+        Trials are sorted based on ``Trial.submit_time``
 
         .. note::
 
             It will return all non-completed trials, including new, reserved, suspended,
             interrupted and broken ones.
 
-        :return: list of non-completed `Trial` objects
+        :return: list of non-completed :class:`orion.core.worker.trial.Trial` objects
         """
         return self._experiment.fetch_noncompleted_trials(with_evc_tree=with_evc_tree)
 
@@ -266,6 +303,8 @@ class ExperimentClient:
     def insert(self, params, results=None, reserve=False):
         """Insert a new trial.
 
+        Experiment must be in writable ('w') or executable ('x') mode.
+
         Parameters
         ----------
         params: dict
@@ -298,19 +337,27 @@ class ExperimentClient:
             - If results have invalid format
         `orion.core.io.database.DuplicateKeyError`
             - If a trial with identical params already exist for the current experiment.
+        `orion.core.utils.exceptions.UnsupportedOperation`
+            If the experiment was not loaded in writable mode.
 
         """
+        self._check_if_writable()
+
         if results and reserve:
             raise ValueError(
-                'Cannot observe a trial and reserve it. A trial with results has status '
-                '`completed` and cannot be reserved.')
+                "Cannot observe a trial and reserve it. A trial with results has status "
+                "`completed` and cannot be reserved."
+            )
         trial = format_trials.dict_to_trial(params, self.space)
         try:
-            self._experiment.register_trial(trial, status='reserved')
+            self._experiment.register_trial(trial, status="reserved")
             self._maintain_reservation(trial)
         except DuplicateKeyError as e:
-            message = 'A trial with params {} already exist for experiment {}-v{}'.format(
-                params, self.name, self.version)
+            message = (
+                "A trial with params {} already exist for experiment {}-v{}".format(
+                    params, self.name, self.version
+                )
+            )
             raise DuplicateKeyError(message) from e
 
         if results:
@@ -330,6 +377,8 @@ class ExperimentClient:
     def reserve(self, trial):
         """Reserve a trial.
 
+        Experiment must be in executable ('x') mode.
+
         Set a trial status to reserve to ensure that concurrent process cannot work on it.
         Trials can only be reserved with status 'new', 'interrupted' or 'suspended'.
 
@@ -344,36 +393,48 @@ class ExperimentClient:
             If trial is reserved by another process
         `ValueError`
             If the trial does not exist in storage.
+        `orion.core.utils.exceptions.UnsupportedOperation`
+            If the experiment was not loaded in executable mode.
 
         Notes
         -----
-        When reserved, a `TrialPacemaker` is started to update an heartbeat in storage. The
-        frequency of the heartbeat is configurable at creation of experiment
-        or with `orion.core.config.worker.heartbeat`.
+        When reserved, a :class:`TrialPacemaker <orion.core.worker.trial_pacemaker.TrialPacemaker>`
+        is started to update an heartbeat in storage. The frequency of the heartbeat is configurable
+        at creation of experiment or with ``orion.core.config.worker.heartbeat``.
         If the process terminates unexpectedly, the heartbeat will cease and remote processes
         may reset the status of the trial to 'interrupted' when the heartbeat has not been updated
-        since twice the value of `heartbeat`.
+        since twice the value of ``heartbeat``.
 
         """
-        if trial.status == 'reserved' and trial.id in self._pacemakers:
-            log.warning('Trial %s is already reserved.', trial.id)
+        self._check_if_executable()
+
+        if trial.status == "reserved" and trial.id in self._pacemakers:
+            log.warning("Trial %s is already reserved.", trial.id)
             return
-        elif trial.status == 'reserved' and trial.id not in self._pacemakers:
-            raise RuntimeError('Trial {} is already reserved by another process.'.format(trial.id))
+        elif trial.status == "reserved" and trial.id not in self._pacemakers:
+            raise RuntimeError(
+                "Trial {} is already reserved by another process.".format(trial.id)
+            )
         try:
-            self._experiment.set_trial_status(trial, 'reserved', heartbeat=self.heartbeat)
+            self._experiment.set_trial_status(
+                trial, "reserved", heartbeat=self.heartbeat
+            )
         except FailedUpdate as e:
             if self.get_trial(trial) is None:
-                raise ValueError('Trial {} does not exist in database.'.format(trial.id)) from e
-            raise RuntimeError('Could not reserve trial {}.'.format(trial.id)) from e
+                raise ValueError(
+                    "Trial {} does not exist in database.".format(trial.id)
+                ) from e
+            raise RuntimeError("Could not reserve trial {}.".format(trial.id)) from e
 
         self._maintain_reservation(trial)
 
-    def release(self, trial, status='interrupted'):
+    def release(self, trial, status="interrupted"):
         """Release a trial.
 
         Release the reservation and stop the heartbeat.
 
+        Experiment must be in writable ('w') or executable ('x') mode.
+
         Parameters
         ----------
         trial: `orion.core.worker.trial.Trial`
@@ -388,21 +449,32 @@ class ExperimentClient:
             If reservation of the trial has been lost prior to releasing it.
         `ValueError`
             If the trial does not exist in storage.
+        `orion.core.utils.exceptions.UnsupportedOperation`
+            If the experiment was not loaded in writable mode.
 
         """
+        self._check_if_writable()
+
         try:
             self._experiment.set_trial_status(trial, status)
         except FailedUpdate as e:
             if self.get_trial(trial) is None:
-                raise ValueError('Trial {} does not exist in database.'.format(trial.id)) from e
+                raise ValueError(
+                    "Trial {} does not exist in database.".format(trial.id)
+                ) from e
             raise RuntimeError(
-                'Reservation for trial {} has been lost before release.'.format(trial.id)) from e
+                "Reservation for trial {} has been lost before release.".format(
+                    trial.id
+                )
+            ) from e
         finally:
             self._release_reservation(trial)
 
     def suggest(self):
         """Suggest a trial to execute.
 
+        Experiment must be in executable ('x') mode.
+
         If any trial is available (new or interrupted), it selects one and reserves it.
         Otherwise, the algorithm is used to generate a new trial that is registered in storage and
         reserved.
@@ -415,18 +487,23 @@ class ExperimentClient:
 
         Raises
         ------
-        `WaitingForTrials`
+        :class:`orion.core.utils.exceptions.WaitingForTrials`
             if the experiment is not completed and algorithm needs to wait for some
             trials to complete before it can suggest new trials.
 
-        `BrokenExperiment`
+        :class:`orion.core.utils.exceptions.BrokenExperiment`
             if too many trials failed to run and the experiment cannot continue.
             This is determined by ``max_broken`` in the configuration of the experiment.
 
-        `SampleTimeout`
+        :class:`orion.core.utils.exceptions.SampleTimeout`
             if the algorithm of the experiment could not sample new unique points.
 
+        :class:`orion.core.utils.exceptions.UnsupportedOperation`
+            If the experiment was not loaded in executable mode.
+
         """
+        self._check_if_executable()
+
         if self.is_broken:
             raise BrokenExperiment("Trials failed too many times")
 
@@ -456,6 +533,8 @@ class ExperimentClient:
     def observe(self, trial, results):
         """Observe trial results
 
+        Experiment must be in executable ('x') mode.
+
         Parameters
         ----------
         trial: `orion.core.worker.trial.Trial`
@@ -478,22 +557,32 @@ class ExperimentClient:
             - If the trial does not exist in storage.
         `RuntimeError`
             If reservation of the trial has been lost prior to releasing it.
+        `orion.core.utils.exceptions.UnsupportedOperation`
+            If the experiment was not loaded in executable mode.
 
         """
+        self._check_if_executable()
+
         trial.results += [Trial.Result(**result) for result in results]
         try:
             self._experiment.update_completed_trial(trial)
-            self.release(trial, 'completed')
+            self.release(trial, "completed")
         except FailedUpdate as e:
             if self.get_trial(trial) is None:
-                raise ValueError('Trial {} does not exist in database.'.format(trial.id)) from e
+                raise ValueError(
+                    "Trial {} does not exist in database.".format(trial.id)
+                ) from e
 
             self._release_reservation(trial)
-            raise RuntimeError('Reservation for trial {} has been lost.'.format(trial.id)) from e
+            raise RuntimeError(
+                "Reservation for trial {} has been lost.".format(trial.id)
+            ) from e
 
     def workon(self, fct, max_trials=infinity, **kwargs):
         """Optimize a given function
 
+        Experiment must be in executable ('x') mode.
+
         Parameters
         ----------
         fct: callable
@@ -511,14 +600,18 @@ class ExperimentClient:
         ------
         `ValueError`
              If results returned by `fct` have invalid format
+        `orion.core.utils.exceptions.UnsupportedOperation`
+            If the experiment was not loaded in executable mode.
 
         """
+        self._check_if_executable()
+
         trials = 0
         kwargs = flatten(kwargs)
         while not self.is_done and trials < max_trials:
             trial = self.suggest()
             if trial is None:
-                log.warning('Algorithm could not sample new points')
+                log.warning("Algorithm could not sample new points")
                 return trials
             kwargs.update(flatten(trial.params))
             results = fct(**unflatten(kwargs))
@@ -528,11 +621,24 @@ class ExperimentClient:
         return trials
 
     def close(self):
-        """Verify that no reserved trials are remaining and unregister atexit()."""
+        """Verify that no reserved trials are remaining and unregister atexit().
+
+        Experiment must be in executable ('x') mode.
+
+        Raises
+        ------
+        `orion.core.utils.exceptions.UnsupportedOperation`
+            If the experiment was not loaded in executable mode.
+
+        """
+        self._check_if_executable()
+
         if self._pacemakers:
-            raise RuntimeError("There is still reserved trials: {}\nRelease all trials before "
-                               "closing the client, using "
-                               "client.release(trial).".format(self._pacemakers.keys()))
+            raise RuntimeError(
+                "There is still reserved trials: {}\nRelease all trials before "
+                "closing the client, using "
+                "client.release(trial).".format(self._pacemakers.keys())
+            )
 
         atexit.unregister(self.set_broken_trials)
 
@@ -547,12 +653,14 @@ class ExperimentClient:
     def _verify_reservation(self, trial):
         if trial.id not in self._pacemakers:
             raise RuntimeError(
-                'Trial {} had no pacemakers. Was is reserved properly?'.format(trial.id))
+                "Trial {} had no pacemakers. Was is reserved properly?".format(trial.id)
+            )
 
-        if self.get_trial(trial).status != 'reserved':
+        if self.get_trial(trial).status != "reserved":
             self._release_reservation(trial)
             raise RuntimeError(
-                'Reservation for trial {} has been lost.'.format(trial.id))
+                "Reservation for trial {} has been lost.".format(trial.id)
+            )
 
     def _maintain_reservation(self, trial):
         self._pacemakers[trial.id] = TrialPacemaker(trial)
@@ -561,5 +669,6 @@ class ExperimentClient:
     def _release_reservation(self, trial):
         if trial.id not in self._pacemakers:
             raise RuntimeError(
-                'Trial {} had no pacemakers. Was is reserved properly?'.format(trial.id))
+                "Trial {} had no pacemakers. Was is reserved properly?".format(trial.id)
+            )
         self._pacemakers.pop(trial.id).stop()
