@@ -1,11 +1,10 @@
 # -*- coding: utf-8 -*-
 """
-:mod:`orion.core.utils.working_dir` -- ContextManager for working directory
-===========================================================================
+ContextManager for working directory
+====================================
+
+ContextManager class to create a permanent directory or a temporary one.
 
-.. module:: working_dir
-   :platform: Unix
-   :synopsis: ContextManager class to create a permanent directory or a temporary one.
 """
 import os
 import tempfile
@@ -39,8 +38,9 @@ class WorkingDir:
             os.makedirs(path, exist_ok=True)
             return path
 
-        self._tmpdir = tempfile.TemporaryDirectory(suffix=self._suffix, prefix=self._prefix,
-                                                   dir=self.working_dir)
+        self._tmpdir = tempfile.TemporaryDirectory(
+            suffix=self._suffix, prefix=self._prefix, dir=self.working_dir
+        )
         return self._tmpdir.name
 
     def __exit__(self, exc_type, exc_value, traceback):
