@@ -1,24 +1,24 @@
 # -*- coding: utf-8 -*-
 # pylint:disable=protected-access,too-many-public-methods,too-many-lines
 """
-:mod:`orion.core.worker.experiment` -- Description of an optimization attempt
-=============================================================================
+Description of an optimization attempt
+======================================
 
-.. module:: experiment
-   :platform: Unix
-   :synopsis: Manage history of trials corresponding to a black box process
+Manage history of trials corresponding to a black box process.
 
 """
 import copy
 import datetime
+import inspect
 import logging
 
 import pandas
 
 from orion.core.evc.adapters import BaseAdapter
 from orion.core.evc.experiment import ExperimentNode
+from orion.core.utils.exceptions import UnsupportedOperation
 from orion.core.utils.flatten import flatten
-from orion.storage.base import FailedUpdate, get_storage, ReadOnlyStorageProtocol
+from orion.storage.base import FailedUpdate, get_storage
 
 log = logging.getLogger(__name__)
 
@@ -30,15 +30,15 @@ class Experiment:
     Attributes
     ----------
     name : str
-       Unique identifier for this experiment per `user`.
+       Unique identifier for this experiment per ``user``.
     id: object
-       id of the experiment in the database if experiment is configured. Value is `None`
+       id of the experiment in the database if experiment is configured. Value is ``None``
        if the experiment is not configured.
     refers : dict or list of `Experiment` objects, after initialization is done.
        A dictionary pointing to a past `Experiment` id, ``refers[parent_id]``, whose
        trials we want to add in the history of completed trials we want to re-use.
        For convenience and database effiency purpose, all experiments of a common tree shares
-       `refers[root_id]`, with the root experiment refering to itself.
+       ``refers[root_id]``, with the root experiment refering to itself.
     version: int
         Current version of this experiment.
     metadata : dict
@@ -84,15 +84,30 @@ class Experiment:
 
     """
 
-    __slots__ = ('name', 'refers', 'metadata', 'pool_size', 'max_trials', 'max_broken', 'version',
-                 'space', 'algorithms', 'producer', 'working_dir', '_id',
-                 '_node', '_storage')
-    non_branching_attrs = ('pool_size', 'max_trials', 'max_broken')
+    __slots__ = (
+        "name",
+        "refers",
+        "metadata",
+        "pool_size",
+        "max_trials",
+        "max_broken",
+        "version",
+        "space",
+        "algorithms",
+        "producer",
+        "working_dir",
+        "_id",
+        "_node",
+        "_storage",
+        "_mode",
+    )
+    non_branching_attrs = ("pool_size", "max_trials", "max_broken")
 
-    def __init__(self, name, version=None):
+    def __init__(self, name, version=None, mode="r"):
         self._id = None
         self.name = name
         self.version = version if version else 1
+        self._mode = mode
         self._node = None
         self.refers = {}
         self.metadata = {}
@@ -103,11 +118,24 @@ class Experiment:
         self.algorithms = None
         self.working_dir = None
         self.producer = {}
-        # this needs to be an attribute because we override it in ExperienceView
         self._storage = get_storage()
 
         self._node = ExperimentNode(self.name, self.version, experiment=self)
 
+    def _check_if_writable(self):
+        if self.mode == "r":
+            calling_function = inspect.stack()[1].function
+            raise UnsupportedOperation(
+                f"Experiment must have write rights to execute `{calling_function}()`"
+            )
+
+    def _check_if_executable(self):
+        if self.mode != "x":
+            calling_function = inspect.stack()[1].function
+            raise UnsupportedOperation(
+                f"Experiment must have execution rights to execute `{calling_function}()`"
+            )
+
     def to_pandas(self, with_evc_tree=False):
         """Builds a dataframe with the trials of the experiment
 
@@ -119,13 +147,25 @@ class Experiment:
 
         """
         columns = [
-            'id', 'experiment_id', 'status', 'suggested', 'reserved', 'completed', 'objective']
+            "id",
+            "experiment_id",
+            "status",
+            "suggested",
+            "reserved",
+            "completed",
+            "objective",
+        ]
 
         data = []
         for trial in self.fetch_trials(with_evc_tree=with_evc_tree):
             row = [
-                trial.id, trial.experiment, trial.status,
-                trial.submit_time, trial.start_time, trial.end_time]
+                trial.id,
+                trial.experiment,
+                trial.status,
+                trial.submit_time,
+                trial.start_time,
+                trial.end_time,
+            ]
             row.append(trial.objective.value if trial.objective else None)
             params = flatten(trial.params)
             for name in self.space.keys():
@@ -142,18 +182,19 @@ class Experiment:
 
     def fetch_trials(self, with_evc_tree=False):
         """Fetch all trials of the experiment"""
-        return self._select_evc_call(with_evc_tree, 'fetch_trials')
+        return self._select_evc_call(with_evc_tree, "fetch_trials")
 
     def get_trial(self, trial=None, uid=None):
-        """Fetch a single Trial, see `orion.storage.base.BaseStorage.get_trial`"""
+        """Fetch a single Trial, see :meth:`orion.storage.base.BaseStorageProtocol.get_trial`"""
         return self._storage.get_trial(trial, uid)
 
     def retrieve_result(self, trial, *args, **kwargs):
-        """See :func:`~orion.storage.BaseStorageProtocol.retrieve_result`"""
+        """See :meth:`orion.storage.base.BaseStorageProtocol.retrieve_result`"""
         return self._storage.retrieve_result(trial, *args, **kwargs)
 
     def set_trial_status(self, *args, **kwargs):
-        """See :func:`~orion.storage.BaseStorageProtocol.set_trial_status`"""
+        """See :meth:`orion.storage.base.BaseStorageProtocol.set_trial_status`"""
+        self._check_if_writable()
         return self._storage.set_trial_status(*args, **kwargs)
 
     def reserve_trial(self, score_handle=None):
@@ -172,12 +213,13 @@ class Experiment:
         Selected `Trial` object, None if could not find any.
 
         """
-        log.debug('reserving trial with (score: %s)', score_handle)
+        self._check_if_executable()
+        log.debug("reserving trial with (score: %s)", score_handle)
 
         self.fix_lost_trials()
 
         selected_trial = self._storage.reserve_trial(self)
-        log.debug('reserved trial (trial: %s)', selected_trial)
+        log.debug("reserved trial (trial: %s)", selected_trial)
         return selected_trial
 
     def fix_lost_trials(self):
@@ -189,16 +231,17 @@ class Experiment:
         trials and set them as interrupted so they can be launched again.
 
         """
+        self._check_if_writable()
         trials = self._storage.fetch_lost_trials(self)
 
         for trial in trials:
-            log.debug('Setting lost trial %s status to interrupted...', trial.id)
+            log.debug("Setting lost trial %s status to interrupted...", trial.id)
 
             try:
-                self._storage.set_trial_status(trial, status='interrupted')
-                log.debug('success')
+                self._storage.set_trial_status(trial, status="interrupted")
+                log.debug("success")
             except FailedUpdate:
-                log.debug('failed')
+                log.debug("failed")
 
     def update_completed_trial(self, trial, results_file=None):
         """Inform database about an evaluated `trial` with results.
@@ -211,10 +254,12 @@ class Experiment:
             Change status from *reserved* to *completed*.
 
         """
-        trial.status = 'completed'
+        self._check_if_executable()
+        trial.status = "completed"
         trial.end_time = datetime.datetime.utcnow()
         self._storage.retrieve_result(trial, results_file)
         # push trial results updates the entire trial status included
+        log.info("Completed trials with results: %s", trial.results)
         self._storage.push_trial_results(trial)
 
     def register_lie(self, lying_trial):
@@ -223,7 +268,7 @@ class Experiment:
         The main difference between fake trial and orignal ones is the addition of a fake objective
         result, and status being set to completed. The id of the fake trial is different than the id
         of the original trial, but the original id can be computed using the hashcode on parameters
-        of the fake trial. See mod:`orion.core.worker.strategy` for more information and the
+        of the fake trial. See :mod:`orion.core.worker.strategy` for more information and the
         Strategist object and generation of fake trials.
 
         Parameters
@@ -239,11 +284,12 @@ class Experiment:
             in the database.
 
         """
-        lying_trial.status = 'completed'
+        self._check_if_writable()
+        lying_trial.status = "completed"
         lying_trial.end_time = datetime.datetime.utcnow()
         self._storage.register_lie(lying_trial)
 
-    def register_trial(self, trial, status='new'):
+    def register_trial(self, trial, status="new"):
         """Register new trial in the database.
 
         Inform database about *new* suggested trial with specific parameter values. Trials may only
@@ -262,6 +308,7 @@ class Experiment:
             in the database.
 
         """
+        self._check_if_writable()
         stamp = datetime.datetime.utcnow()
         trial.experiment = self._id
         trial.status = status
@@ -282,7 +329,7 @@ class Experiment:
 
         :return: list of `Trial` objects
         """
-        return self._select_evc_call(with_evc_tree, 'fetch_trials_by_status', status)
+        return self._select_evc_call(with_evc_tree, "fetch_trials_by_status", status)
 
     def fetch_noncompleted_trials(self, with_evc_tree=False):
         """Fetch non-completed trials of this `Experiment` instance.
@@ -296,7 +343,7 @@ class Experiment:
 
         :return: list of non-completed `Trial` objects
         """
-        return self._select_evc_call(with_evc_tree, 'fetch_noncompleted_trials')
+        return self._select_evc_call(with_evc_tree, "fetch_noncompleted_trials")
 
     # pylint: disable=invalid-name
     @property
@@ -307,16 +354,20 @@ class Experiment:
         """
         return self._id
 
+    @property
+    def mode(self):
+        """Return the access right of the experiment
+
+        {'r': read, 'w': read/write, 'x': read/write/execute}
+        """
+        return self._mode
+
     @property
     def node(self):
         """Node of the experiment in the version control tree.
 
         Value is `None` if the experiment is not connected to the version control tree.
 
-        .. seealso::
-
-            :py:meth:`orion.core.worker.experiment.Experiment.connect_to_version_control_tree`
-
         """
         return self._node
 
@@ -324,8 +375,8 @@ class Experiment:
     def is_done(self):
         """Return True, if this experiment is considered to be finished.
 
-        1. Count how many trials have been completed and compare with `max_trials`.
-        2. Ask `algorithms` if they consider there is a chance for further improvement, and
+        1. Count how many trials have been completed and compare with ``max_trials``.
+        2. Ask ``algorithms`` if they consider there is a chance for further improvement, and
            verify is there is any pending trial.
 
         .. note::
@@ -337,14 +388,14 @@ class Experiment:
         num_completed_trials = 0
         num_pending_trials = 0
         for trial in trials:
-            if trial.status == 'completed':
+            if trial.status == "completed":
                 num_completed_trials += 1
-            elif trial.status in ['new', 'reserved', 'interrupted']:
+            elif trial.status in ["new", "reserved", "interrupted"]:
                 num_pending_trials += 1
 
-        return (
-            (num_completed_trials >= self.max_trials) or
-            (self.algorithms.is_done and num_pending_trials == 0))
+        return (num_completed_trials >= self.max_trials) or (
+            self.algorithms.is_done and num_pending_trials == 0
+        )
 
     @property
     def is_broken(self):
@@ -363,19 +414,29 @@ class Experiment:
         """Return a copy of an `Experiment` configuration as a dictionary."""
         config = dict()
         for attrname in self.__slots__:
-            if attrname.startswith('_'):
+            if attrname.startswith("_"):
                 continue
             attribute = copy.deepcopy(getattr(self, attrname))
             config[attrname] = attribute
-            if attrname in ['algorithms', 'space']:
+            if attrname == "space":
                 config[attrname] = attribute.configuration
-            elif attrname == "refers" and isinstance(attribute.get("adapter"), BaseAdapter):
-                config[attrname]['adapter'] = config[attrname]['adapter'].configuration
-            elif attrname == "producer" and attribute.get("strategy"):
-                config[attrname]['strategy'] = config[attrname]['strategy'].configuration
+            elif attrname == "algorithms" and not isinstance(attribute, dict):
+                config[attrname] = attribute.configuration
+            elif attrname == "refers" and isinstance(
+                attribute.get("adapter"), BaseAdapter
+            ):
+                config[attrname]["adapter"] = config[attrname]["adapter"].configuration
+            elif (
+                attrname == "producer"
+                and attribute.get("strategy")
+                and not isinstance(attribute["strategy"], dict)
+            ):
+                config[attrname]["strategy"] = config[attrname][
+                    "strategy"
+                ].configuration
 
         if self.id is not None:
-            config['_id'] = self.id
+            config["_id"] = self.id
 
         return copy.deepcopy(config)
 
@@ -404,70 +465,35 @@ class Experiment:
            Elapsed time.
 
         """
-        completed_trials = self.fetch_trials_by_status('completed')
+        completed_trials = self.fetch_trials_by_status("completed")
 
         if not completed_trials:
             return dict()
         stats = dict()
-        stats['trials_completed'] = len(completed_trials)
-        stats['best_trials_id'] = None
+        stats["trials_completed"] = len(completed_trials)
+        stats["best_trials_id"] = None
         trial = completed_trials[0]
-        stats['best_evaluation'] = trial.objective.value
-        stats['best_trials_id'] = trial.id
-        stats['start_time'] = self.metadata['datetime']
-        stats['finish_time'] = stats['start_time']
+        stats["best_evaluation"] = trial.objective.value
+        stats["best_trials_id"] = trial.id
+        stats["start_time"] = self.metadata["datetime"]
+        stats["finish_time"] = stats["start_time"]
         for trial in completed_trials:
             # All trials are going to finish certainly after the start date
             # of the experiment they belong to
-            if trial.end_time > stats['finish_time']:  # pylint:disable=no-member
-                stats['finish_time'] = trial.end_time
+            if trial.end_time > stats["finish_time"]:  # pylint:disable=no-member
+                stats["finish_time"] = trial.end_time
             objective = trial.objective.value
-            if objective < stats['best_evaluation']:
-                stats['best_evaluation'] = objective
-                stats['best_trials_id'] = trial.id
-        stats['duration'] = stats['finish_time'] - stats['start_time']
+            if objective < stats["best_evaluation"]:
+                stats["best_evaluation"] = objective
+                stats["best_trials_id"] = trial.id
+        stats["duration"] = stats["finish_time"] - stats["start_time"]
 
         return stats
 
     def __repr__(self):
         """Represent the object as a string."""
-        return "Experiment(name=%s, metadata.user=%s, version=%s)" % \
-            (self.name, self.metadata['user'], self.version)
-
-
-# pylint: disable=too-few-public-methods
-class ExperimentView(object):
-    """Non-writable view of an experiment
-
-    .. seealso::
-
-        :py:class:`orion.core.worker.experiment.Experiment` for writable experiments.
-
-    """
-
-    __slots__ = ('_experiment', )
-
-    #                     Attributes
-    valid_attributes = (["_id", "name", "refers", "metadata", "pool_size", "max_trials",
-                         "max_broken", "version", "space", "working_dir", "producer"] +
-                        # Properties
-                        ["id", "node", "is_done", "is_broken", "algorithms", "stats",
-                         "configuration"] +
-                        # Methods
-                        ["to_pandas", "fetch_trials", "fetch_trials_by_status", "get_trial"])
-
-    def __init__(self, experiment):
-        self._experiment = experiment
-        self._experiment._storage = ReadOnlyStorageProtocol(experiment._storage)
-
-    def __getattr__(self, name):
-        """Get attribute only if valid"""
-        if name not in self.valid_attributes:
-            raise AttributeError("Cannot access attribute %s on view-only experiments." % name)
-
-        return getattr(self._experiment, name)
-
-    def __repr__(self):
-        """Represent the object as a string."""
-        return "ExperimentView(name=%s, metadata.user=%s, version=%s)" % \
-            (self.name, self.metadata['user'], self.version)
+        return "Experiment(name=%s, metadata.user=%s, version=%s)" % (
+            self.name,
+            self.metadata["user"],
+            self.version,
+        )
