@@ -1,17 +1,16 @@
 # -*- coding: utf-8 -*-
 """
-:mod:`orion.core.worker.trial_monitor` -- Monitor trial execution
-=================================================================
-.. module:: trial_monitor
-   :platform: Unix
-   :synopsis: Monitor trials and update their heartbeat
+Trial Pacemaker
+===============
+
+Monitor trials and update their heartbeat
 
 """
 import threading
 
 from orion.storage.base import get_storage
 
-STOPPED_STATUS = {'completed', 'interrupted', 'suspended'}
+STOPPED_STATUS = {"completed", "interrupted", "suspended"}
 
 
 class TrialPacemaker(threading.Thread):
