@@ -1,77 +1,76 @@
 # -*- coding: utf-8 -*-
 """
-:mod:`orion.storage.track` -- Track Storage Protocol
-====================================================
+Track Storage Protocol
+======================
 
-.. module:: base
-   :platform: Unix
-   :synopsis: Implement a storage protocol to allow Orion to use track as a storage method
+Implement a storage protocol to allow Orion to use track as a storage method.
 
 """
 
-from collections import defaultdict
 import copy
 import datetime
 import hashlib
 import logging
 import sys
 import warnings
+from collections import defaultdict
 
 import orion.core
 from orion.core.io.database import DuplicateKeyError
 from orion.core.utils.flatten import flatten, unflatten
-from orion.core.worker.trial import Trial as OrionTrial, validate_status
+from orion.core.worker.trial import Trial as OrionTrial
+from orion.core.worker.trial import validate_status
 from orion.storage.base import BaseStorageProtocol, FailedUpdate, get_uid
 
 log = logging.getLogger(__name__)
 
 
 # TODO: Remove this when factory is reworked
-class Track:    # noqa: F811
+class Track:  # noqa: F811
     """Forward declaration because of a weird factory bug where Track is not found"""
 
     def __init__(self, uri):
-        assert False, 'This should not be called'
+        assert False, "This should not be called"
 
 
 HAS_TRACK = False
 REASON = None
 try:
     from track.client import TrackClient
+    from track.persistence.local import ConcurrentWrite
     from track.persistence.utils import parse_uri
     from track.serialization import to_json
-    from track.structure import CustomStatus, Status as TrackStatus
-    from track.structure import Project, Trial as TrackTrial, TrialGroup
-    from track.persistence.local import ConcurrentWrite
+    from track.structure import CustomStatus, Project
+    from track.structure import Status as TrackStatus
+    from track.structure import Trial as TrackTrial
+    from track.structure import TrialGroup
     from track.utils import ItemNotFound
 
     HAS_TRACK = True
 except ImportError:
-    REASON = 'Track is not installed'
+    REASON = "Track is not installed"
 
 except SyntaxError:
     major, minor, patch, _, _ = sys.version_info
 
     if minor < 6:
-        REASON = 'Python is too old'
-        log.warning('Track does not support python < 3.6!')
+        REASON = "Python is too old"
+        log.warning("Track does not support python < 3.6!")
     else:
         raise
 
 
 if HAS_TRACK:
     _status = [
-        CustomStatus('new', TrackStatus.CreatedGroup.value + 1),
-        CustomStatus('reserved', TrackStatus.CreatedGroup.value + 2),
+        CustomStatus("new", TrackStatus.CreatedGroup.value + 1),
+        CustomStatus("reserved", TrackStatus.CreatedGroup.value + 2),
     ]
 
-    _status_dict = {
-        s.name: s for s in _status
-    }
-    _status_dict['completed'] = TrackStatus.Completed
-    _status_dict['interrupted'] = TrackStatus.Interrupted
-    _status_dict['broken'] = TrackStatus.Broken
-    _status_dict['suspended'] = TrackStatus.Suspended
+    _status_dict = {s.name: s for s in _status}
+    _status_dict["completed"] = TrackStatus.Completed
+    _status_dict["interrupted"] = TrackStatus.Interrupted
+    _status_dict["broken"] = TrackStatus.Broken
+    _status_dict["suspended"] = TrackStatus.Suspended
 
 
 def get_track_status(val):
@@ -129,15 +128,18 @@ class TrialAdapter:
         self.objectives_values = None
         self._results = []
 
-    def _repr_values(self, values, sep=','):
+    def _repr_values(self, values, sep=","):
         """Represent with a string the given values."""
         return
 
     def __str__(self):
         """Represent partially with a string."""
-        param_rep = ','.join(map(lambda value: "{0.name}:{0.value}".format(value), self._params))
+        param_rep = ",".join(
+            map(lambda value: "{0.name}:{0.value}".format(value), self._params)
+        )
         ret = "TrialAdapter(uid={3}, experiment={0}, status={1}, params={2})".format(
-            repr(self.experiment[:10]), repr(self.status), param_rep, self.storage.uid)
+            repr(self.experiment[:10]), repr(self.status), param_rep, self.storage.uid
+        )
         return ret
 
     __repr__ = __str__
@@ -152,7 +154,9 @@ class TrialAdapter:
     @property
     def hearbeat(self):
         """See `~orion.core.worker.trial.Trial`"""
-        return datetime.datetime.utcfromtimestamp(self.storage.metadata.get('heartbeat', 0))
+        return datetime.datetime.utcfromtimestamp(
+            self.storage.metadata.get("heartbeat", 0)
+        )
 
     @property
     def id(self):
@@ -173,11 +177,13 @@ class TrialAdapter:
         if self.memory is not None:
             return self.memory._params
 
-        types = self.storage.metadata['params_types']
+        types = self.storage.metadata["params_types"]
         params = flatten(self.storage.parameters)
 
         return [
-            OrionTrial.Param(name=add_leading_slash(name), value=params.get(name), type=vtype)
+            OrionTrial.Param(
+                name=add_leading_slash(name), value=params.get(name), type=vtype
+            )
             for name, vtype in types.items()
         ]
 
@@ -200,18 +206,20 @@ class TrialAdapter:
     def to_dict(self):
         """See `~orion.core.worker.trial.Trial`"""
         trial = copy.deepcopy(self.storage.metadata)
-        trial.update({
-            'results': [r.to_dict() for r in self.results],
-            'params': [p.to_dict() for p in self._params],
-            '_id': self.storage.uid,
-            'submit_time': self.submit_time,
-            'experiment': self.experiment,
-            'status': self.status
-        })
+        trial.update(
+            {
+                "results": [r.to_dict() for r in self.results],
+                "params": [p.to_dict() for p in self._params],
+                "_id": self.storage.uid,
+                "submit_time": self.submit_time,
+                "experiment": self.experiment,
+                "status": self.status,
+            }
+        )
 
-        trial.pop('_update_count', 0)
-        trial.pop('metric_types', 0)
-        trial.pop('params_types')
+        trial.pop("_update_count", 0)
+        trial.pop("metric_types", 0)
+        trial.pop("params_types")
 
         return trial
 
@@ -224,11 +232,14 @@ class TrialAdapter:
     @property
     def objective(self):
         """See `~orion.core.worker.trial.Trial`"""
+
         def result(val):
-            return OrionTrial.Result(name=self.objective_key, value=val, type='objective')
+            return OrionTrial.Result(
+                name=self.objective_key, value=val, type="objective"
+            )
 
         if self.objective_key is None:
-            raise RuntimeError('no objective key was defined!')
+            raise RuntimeError("no objective key was defined!")
 
         self.objectives_values = []
 
@@ -257,18 +268,22 @@ class TrialAdapter:
         self._results = []
 
         for k, values in self.storage.metrics.items():
-            result_type = 'statistic'
+            result_type = "statistic"
             if k == self.objective_key:
-                result_type = 'objective'
+                result_type = "objective"
 
             if isinstance(values, dict):
                 items = list(values.items())
                 items.sort(key=lambda v: v[0])
 
                 val = items[-1][1]
-                self._results.append(OrionTrial.Result(name=k, type=result_type, value=val))
+                self._results.append(
+                    OrionTrial.Result(name=k, type=result_type, value=val)
+                )
             elif isinstance(values, list):
-                self._results.append(OrionTrial.Result(name=k, type=result_type, value=values[-1]))
+                self._results.append(
+                    OrionTrial.Result(name=k, type=result_type, value=values[-1])
+                )
 
         return self._results
 
@@ -290,22 +305,24 @@ class TrialAdapter:
     @property
     def submit_time(self):
         """See `~orion.core.worker.trial.Trial`"""
-        return datetime.datetime.utcfromtimestamp(self.storage.metadata.get('submit_time'))
+        return datetime.datetime.utcfromtimestamp(
+            self.storage.metadata.get("submit_time")
+        )
 
     @property
     def end_time(self):
         """See `~orion.core.worker.trial.Trial`"""
-        return datetime.datetime.utcfromtimestamp(self.storage.metadata.get('end_time'))
+        return datetime.datetime.utcfromtimestamp(self.storage.metadata.get("end_time"))
 
     @end_time.setter
     def end_time(self, value):
         """See `~orion.core.worker.trial.Trial`"""
-        self.storage.metadata['end_time'] = value
+        self.storage.metadata["end_time"] = value
 
     @property
     def heartbeat(self):
         """Trial Heartbeat"""
-        heartbeat = self.storage.metadata.get('heartbeat')
+        heartbeat = self.storage.metadata.get("heartbeat")
         if heartbeat:
             return datetime.datetime.utcfromtimestamp(heartbeat)
         return None
@@ -313,12 +330,12 @@ class TrialAdapter:
     @property
     def parents(self):
         """See `~orion.core.worker.trial.Trial`"""
-        return self.storage.metadata.get('parent', [])
+        return self.storage.metadata.get("parent", [])
 
     @parents.setter
     def parents(self, other):
         """See `~orion.core.worker.trial.Trial`"""
-        self.storage.metadata['parent'] = other
+        self.storage.metadata["parent"] = other
 
 
 def experiment_uid(exp=None, name=None, version=None):
@@ -330,12 +347,12 @@ def experiment_uid(exp=None, name=None, version=None):
         version = exp.version
 
     sha = hashlib.sha256()
-    sha.update(name.encode('utf8'))
+    sha.update(name.encode("utf8"))
     sha.update(bytes([version]))
     return sha.hexdigest()
 
 
-class Track(BaseStorageProtocol):   # noqa: F811
+class Track(BaseStorageProtocol):  # noqa: F811
     """Implement a generic protocol to allow Orion to communicate using
     different storage backend
 
@@ -351,18 +368,18 @@ class Track(BaseStorageProtocol):   # noqa: F811
         if not HAS_TRACK:
             # We ignored the import error above in case we did not need track
             # but now that we do we can rethrow it
-            raise ImportError('Track is not installed!')
+            raise ImportError("Track is not installed!")
 
         self.uri = uri
-        self.options = parse_uri(uri)['query']
+        self.options = parse_uri(uri)["query"]
 
         self.client = TrackClient(uri)
         self.backend = self.client.protocol
         self.project = None
         self.group = None
-        self.objective = self.options.get('objective')
+        self.objective = self.options.get("objective")
         self.lies = dict()
-        assert self.objective is not None, 'An objective should be defined!'
+        assert self.objective is not None, "An objective should be defined!"
 
     def _get_project(self, name):
         if self.project is None:
@@ -371,33 +388,33 @@ class Track(BaseStorageProtocol):   # noqa: F811
             if self.project is None:
                 self.project = self.backend.new_project(Project(name=name))
 
-        assert self.project, 'Project should have been found'
+        assert self.project, "Project should have been found"
 
     def create_experiment(self, config):
         """Insert a new experiment inside the database"""
-        self._get_project(config['name'])
+        self._get_project(config["name"])
 
         self.group = self.backend.new_trial_group(
             TrialGroup(
-                name=experiment_uid(name=config['name'], version=config['version']),
+                name=experiment_uid(name=config["name"], version=config["version"]),
                 project_id=self.project.uid,
-                metadata=to_json(config)
+                metadata=to_json(config),
             )
         )
 
         if self.group is None:
-            raise DuplicateKeyError('Experiment was already created')
+            raise DuplicateKeyError("Experiment was already created")
 
-        config['_id'] = self.group.uid
+        config["_id"] = self.group.uid
         return config
 
     def update_experiment(self, experiment=None, uid=None, where=None, **kwargs):
-        """See :func:`~orion.storage.BaseStorageProtocol.update_experiment`"""
+        """See :meth:`orion.storage.base.BaseStorageProtocol.update_experiment`"""
         uid = get_uid(experiment, uid)
 
-        self.group = self.backend.fetch_and_update_group({
-            '_uid': uid
-        }, 'set_group_metadata', **kwargs)
+        self.group = self.backend.fetch_and_update_group(
+            {"_uid": uid}, "set_group_metadata", **kwargs
+        )
 
         return self.group
 
@@ -405,14 +422,14 @@ class Track(BaseStorageProtocol):   # noqa: F811
         """Fetch all experiments that match the query"""
         new_query = {}
         for k, v in query.items():
-            if k == 'name':
-                new_query['metadata.name'] = v
+            if k == "name":
+                new_query["metadata.name"] = v
 
-            elif k.startswith('metadata'):
-                new_query['metadata.{}'.format(k)] = v
+            elif k.startswith("metadata"):
+                new_query["metadata.{}".format(k)] = v
 
-            elif k == '_id':
-                new_query['_uid'] = v
+            elif k == "_id":
+                new_query["_uid"] = v
 
             else:
                 new_query[k] = v
@@ -421,15 +438,17 @@ class Track(BaseStorageProtocol):   # noqa: F811
 
         experiments = []
         for group in groups:
-            version = group.metadata.get('version', 0)
+            version = group.metadata.get("version", 0)
 
             # metadata is experiment config
             exp = group.metadata
-            exp.update({
-                '_id': group.uid,
-                'version': version,
-                'name': group.project_id,
-            })
+            exp.update(
+                {
+                    "_id": group.uid,
+                    "version": version,
+                    "name": group.project_id,
+                }
+            )
 
             experiments.append(exp)
 
@@ -442,16 +461,20 @@ class Track(BaseStorageProtocol):   # noqa: F811
 
         metadata = dict()
         # pylint: disable=protected-access
-        metadata['params_types'] = {remove_leading_slash(p.name): p.type for p in trial._params}
-        metadata['submit_time'] = to_json(trial.submit_time)
-        metadata['end_time'] = to_json(trial.end_time)
-        metadata['worker'] = trial.worker
-        metadata['metric_types'] = {remove_leading_slash(p.name): p.type for p in trial.results}
-        metadata['metric_types'][self.objective] = 'objective'
+        metadata["params_types"] = {
+            remove_leading_slash(p.name): p.type for p in trial._params
+        }
+        metadata["submit_time"] = to_json(trial.submit_time)
+        metadata["end_time"] = to_json(trial.end_time)
+        metadata["worker"] = trial.worker
+        metadata["metric_types"] = {
+            remove_leading_slash(p.name): p.type for p in trial.results
+        }
+        metadata["metric_types"][self.objective] = "objective"
         heartbeat = to_json(trial.heartbeat)
         if heartbeat is None:
             heartbeat = 0
-        metadata['heartbeat'] = heartbeat
+        metadata["heartbeat"] = heartbeat
 
         metrics = defaultdict(list)
         for p in trial.results:
@@ -460,18 +483,21 @@ class Track(BaseStorageProtocol):   # noqa: F811
         if self.project is None:
             self._get_project(self.group.project_id)
 
-        trial = self.backend.new_trial(TrackTrial(
-            _hash=trial.hash_name,
-            status=get_track_status(trial.status),
-            project_id=self.project.uid,
-            group_id=self.group.uid,
-            parameters=trial.params,
-            metadata=metadata,
-            metrics=metrics
-        ), auto_increment=False)
+        trial = self.backend.new_trial(
+            TrackTrial(
+                _hash=trial.hash_name,
+                status=get_track_status(trial.status),
+                project_id=self.project.uid,
+                group_id=self.group.uid,
+                parameters=trial.params,
+                metadata=metadata,
+                metrics=metrics,
+            ),
+            auto_increment=False,
+        )
 
         if trial is None:
-            raise DuplicateKeyError('Was not able to register Trial!')
+            raise DuplicateKeyError("Was not able to register Trial!")
 
         return TrialAdapter(trial, objective=self.objective)
 
@@ -490,16 +516,17 @@ class Track(BaseStorageProtocol):   # noqa: F811
             Fake trial to register in the database
 
         """
-        warnings.warn('Track does not persist lies!')
+        warnings.warn("Track does not persist lies!")
 
         if trial.id in self.lies:
-            raise DuplicateKeyError('Lie already exists')
+            raise DuplicateKeyError("Lie already exists")
 
         self.lies[trial.id] = trial
         return trial
 
     def _fetch_trials(self, query, *args, **kwargs):
         """Fetch all the trials that match the query"""
+
         def sort_key(item):
             submit_time = item.submit_time
             if submit_time is None:
@@ -510,26 +537,27 @@ class Track(BaseStorageProtocol):   # noqa: F811
 
         new_query = {}
         for k, v in query.items():
-            if k == 'experiment':
-                new_query['group_id'] = v
+            if k == "experiment":
+                new_query["group_id"] = v
 
-            elif k == 'heartbeat':
-                new_query['metadata.heartbeat'] = v
+            elif k == "heartbeat":
+                new_query["metadata.heartbeat"] = v
 
-            elif k == '_id':
-                new_query['uid'] = v
+            elif k == "_id":
+                new_query["uid"] = v
 
-            elif k == 'end_time':
-                new_query['metadata.end_time'] = v
+            elif k == "end_time":
+                new_query["metadata.end_time"] = v
 
-            elif k == 'status' and isinstance(v, str):
-                new_query['status'] = get_track_status(v)
+            elif k == "status" and isinstance(v, str):
+                new_query["status"] = get_track_status(v)
 
             else:
                 new_query[k] = v
 
         trials = [
-            TrialAdapter(t, objective=self.objective) for t in self.backend.fetch_trials(new_query)
+            TrialAdapter(t, objective=self.objective)
+            for t in self.backend.fetch_trials(new_query)
         ]
         trials.sort(key=sort_key)
         return trials
@@ -544,20 +572,21 @@ class Track(BaseStorageProtocol):   # noqa: F811
         refreshed_trial = self.backend.get_trial(trial)[0]
         new_trial = TrialAdapter(refreshed_trial, objective=self.objective)
 
-        assert new_trial.objective is not None, 'Trial should have returned an objective value!'
+        assert (
+            new_trial.objective is not None
+        ), "Trial should have returned an objective value!"
 
-        log.info("trial objective is (%s: %s)", self.objective, new_trial.objective.value)
+        log.info(
+            "trial objective is (%s: %s)", self.objective, new_trial.objective.value
+        )
         return new_trial
 
     def fetch_pending_trials(self, experiment):
-        """See :func:`~orion.storage.BaseStorageProtocol.fetch_pending_trials`"""
-        pending_status = ['new', 'suspended', 'interrupted']
+        """See :meth:`orion.storage.base.BaseStorageProtocol.fetch_pending_trials`"""
+        pending_status = ["new", "suspended", "interrupted"]
         pending_status = [get_track_status(s) for s in pending_status]
 
-        query = dict(
-            group_id=experiment.id,
-            status={'$in': pending_status}
-        )
+        query = dict(group_id=experiment.id, status={"$in": pending_status})
 
         return self._fetch_trials(query)
 
@@ -573,10 +602,11 @@ class Track(BaseStorageProtocol):   # noqa: F811
         """
         validate_status(status)
         try:
-            result_trial = self.backend.fetch_and_update_trial({
-                'uid': trial.id,
-                'status': get_track_status(trial.status)
-            }, 'set_trial_status', status=get_track_status(status))
+            result_trial = self.backend.fetch_and_update_trial(
+                {"uid": trial.id, "status": get_track_status(trial.status)},
+                "set_trial_status",
+                status=get_track_status(status),
+            )
 
         except ItemNotFound as e:
             raise FailedUpdate() from e
@@ -585,17 +615,17 @@ class Track(BaseStorageProtocol):   # noqa: F811
         return result_trial
 
     def fetch_trials(self, experiment=None, uid=None):
-        """See :func:`~orion.storage.BaseStorageProtocol.fetch_trials`"""
+        """See :meth:`orion.storage.base.BaseStorageProtocol.fetch_trials`"""
         uid = get_uid(experiment, uid)
 
         return self._fetch_trials(dict(group_id=uid))
 
     def get_trial(self, trial=None, uid=None):
-        """See :func:`~orion.storage.BaseStorageProtocol.get_trials`"""
+        """See :meth:`orion.storage.base.BaseStorageProtocol.get_trial`"""
         uid = get_uid(trial, uid)
 
         _hash, _rev = 0, 0
-        data = uid.split('_', maxsplit=1)
+        data = uid.split("_", maxsplit=1)
 
         if len(data) == 1:
             _hash = data[0]
@@ -614,15 +644,13 @@ class Track(BaseStorageProtocol):   # noqa: F811
     def reserve_trial(self, experiment):
         """Select a pending trial and reserve it for the worker"""
         query = dict(
-            group_id=experiment.id,
-            status={'$in': ['new', 'suspended', 'interrupted']}
+            group_id=experiment.id, status={"$in": ["new", "suspended", "interrupted"]}
         )
 
         try:
             trial = self.backend.fetch_and_update_trial(
-                query,
-                'set_trial_status',
-                status=get_track_status('reserved'))
+                query, "set_trial_status", status=get_track_status("reserved")
+            )
 
         except ItemNotFound:
             return None
@@ -633,13 +661,13 @@ class Track(BaseStorageProtocol):   # noqa: F811
         return TrialAdapter(trial, objective=self.objective)
 
     def update_trials(self, experiment=None, uid=None, where=None, **kwargs):
-        """See :func:`~orion.storage.BaseStorageProtocol.update_trials`"""
+        """See :meth:`orion.storage.base.BaseStorageProtocol.update_trials`"""
         uid = get_uid(experiment, uid)
 
         if where is None:
             where = dict()
 
-        where['group_id'] = uid
+        where["group_id"] = uid
 
         count = 0
         for trial in self._fetch_trials(where):
@@ -647,7 +675,7 @@ class Track(BaseStorageProtocol):   # noqa: F811
 
         return count
 
-    _ignore_updates_for = {'results', 'params', '_id'}
+    _ignore_updates_for = {"results", "params", "_id"}
 
     def update_trial(self, trial=None, uid=None, **kwargs):
         """Update the fields of a given trials
@@ -676,7 +704,7 @@ class Track(BaseStorageProtocol):   # noqa: F811
                 trial = trial.storage
 
             for key, value in kwargs.items():
-                if key == 'status':
+                if key == "status":
                     self.backend.set_trial_status(trial, get_track_status(value))
                 elif key in self._ignore_updates_for:
                     continue
@@ -693,12 +721,14 @@ class Track(BaseStorageProtocol):   # noqa: F811
         some given time delta (5 minutes by default)
         """
         heartbeat = orion.core.config.worker.heartbeat
-        threshold = to_epoch(datetime.datetime.utcnow() - datetime.timedelta(seconds=heartbeat * 5))
-        lte_comparison = {'$lte': threshold}
+        threshold = to_epoch(
+            datetime.datetime.utcnow() - datetime.timedelta(seconds=heartbeat * 5)
+        )
+        lte_comparison = {"$lte": threshold}
         query = {
-            'experiment': experiment.id,
-            'status': 'reserved',
-            'heartbeat': lte_comparison
+            "experiment": experiment.id,
+            "status": "reserved",
+            "heartbeat": lte_comparison,
         }
 
         return self._fetch_trials(query)
@@ -711,8 +741,7 @@ class Track(BaseStorageProtocol):   # noqa: F811
     def fetch_noncompleted_trials(self, experiment):
         """Fetch all non completed trials"""
         query = dict(
-            group_id=experiment.id,
-            status={'$ne': get_track_status('completed')}
+            group_id=experiment.id, status={"$ne": get_track_status("completed")}
         )
         return self.backend.fetch_trials(query)
 
@@ -723,13 +752,14 @@ class Track(BaseStorageProtocol):   # noqa: F811
 
     def count_completed_trials(self, experiment):
         """Count the number of completed trials"""
-        return len(self._fetch_trials(dict(status='completed', group_id=experiment.id)))
+        return len(self._fetch_trials(dict(status="completed", group_id=experiment.id)))
 
     def count_broken_trials(self, experiment):
         """Count the number of broken trials"""
-        return len(self._fetch_trials(dict(status='broken', group_id=experiment.id)))
+        return len(self._fetch_trials(dict(status="broken", group_id=experiment.id)))
 
     def update_heartbeat(self, trial):
         """Update trial's heartbeat"""
-        self.backend.log_trial_metadata(trial.storage,
-                                        heartbeat=to_epoch(datetime.datetime.utcnow()))
+        self.backend.log_trial_metadata(
+            trial.storage, heartbeat=to_epoch(datetime.datetime.utcnow())
+        )
