@@ -10,14 +10,14 @@ from orion.client import report_results
 def function(x):
     """Evaluate partial information of a quadratic."""
     y = x - 34.56789
-    return 4 * y**2 + 23.4, 8 * y
+    return 4 * y ** 2 + 23.4, 8 * y
 
 
 def execute():
     """Execute a simple pipeline as an example."""
     # 1. Receive inputs as you want
     parser = argparse.ArgumentParser()
-    parser.add_argument('-x', type=float, required=True)
+    parser.add_argument("-x", type=float, required=True)
     inputs = parser.parse_args()
 
     # 2. Perform computations
@@ -25,14 +25,8 @@ def execute():
 
     # 3. Gather and report results
     results = list()
-    results.append(dict(
-        name='example_objective',
-        type='objective',
-        value=y))
-    results.append(dict(
-        name='example_gradient',
-        type='gradient',
-        value=[dy]))
+    results.append(dict(name="example_objective", type="objective", value=y))
+    results.append(dict(name="example_gradient", type="gradient", value=[dy]))
 
     report_results(results)
 
