@@ -6,8 +6,6 @@ import pytest
 
 from orion.core.evc.adapters import Adapter, CodeChange
 from orion.core.evc.experiment import ExperimentNode
-from orion.core.worker.experiment import ExperimentView
-
 
 # To avoid flake8 issues
 build_trimmed_tree = "dummy"
@@ -18,12 +16,14 @@ build_trimmed_tree = "dummy"
 @pytest.mark.usefixtures("refers_id_substitution")
 def test_parent_fetch_trials(create_db_instance):
     """Test that experiment fetch trials from parent properly (adapters are muted)"""
-    experiment_name = 'supernaedo2.3'
-    root_name = 'supernaedo2'
-    leaf_names = ['supernaedo2.3']
+    experiment_name = "supernaedo2.3"
+    root_name = "supernaedo2"
+    leaf_names = ["supernaedo2.3"]
 
     experiment = ExperimentView(experiment_name)
-    exp_node = ExperimentNode(experiment.name, experiment.version, experiment=experiment)
+    exp_node = ExperimentNode(
+        experiment.name, experiment.version, experiment=experiment
+    )
     exp_node = build_trimmed_tree(experiment, root_name, leaf_names)
 
     assert exp_node.item.name == experiment_name
@@ -37,9 +37,9 @@ def test_parent_fetch_trials(create_db_instance):
     experiment.connect_to_version_control_tree(exp_node)
 
     for node in exp_node.root:
-        node.item._experiment.refers['adapter'] = Adapter.build([])
+        node.item._experiment.refers["adapter"] = Adapter.build([])
 
-    query = {'status': 'completed'}
+    query = {"status": "completed"}
     assert len(experiment.fetch_trials(query)) == 4
     assert len(experiment._experiment._node.parent.item.fetch_trials(query)) == 6
     assert len(experiment.fetch_trials_tree(query)) == 10
@@ -50,9 +50,9 @@ def test_parent_fetch_trials(create_db_instance):
 @pytest.mark.usefixtures("refers_id_substitution")
 def test_children_fetch_trials(create_db_instance):
     """Test that experiment fetch trials from children properly (adapters are muted)"""
-    experiment_name = 'supernaedo2'
-    root_name = 'supernaedo2'
-    leaf_names = ['supernaedo2.3']
+    experiment_name = "supernaedo2"
+    root_name = "supernaedo2"
+    leaf_names = ["supernaedo2.3"]
 
     experiment = ExperimentView(experiment_name)
     exp_node = build_trimmed_tree(experiment, root_name, leaf_names)
@@ -68,9 +68,9 @@ def test_children_fetch_trials(create_db_instance):
     experiment.connect_to_version_control_tree(exp_node)
 
     for node in exp_node.root:
-        node.item._experiment.refers['adapter'] = Adapter.build([])
+        node.item._experiment.refers["adapter"] = Adapter.build([])
 
-    query = {'status': 'completed'}
+    query = {"status": "completed"}
     assert len(experiment.fetch_trials(query)) == 6
     assert len(experiment._experiment._node.children[0].item.fetch_trials(query)) == 4
     assert len(experiment.fetch_trials_tree(query)) == 10
@@ -81,9 +81,9 @@ def test_children_fetch_trials(create_db_instance):
 @pytest.mark.usefixtures("refers_id_substitution")
 def test_parent_parent_fetch_trials(create_db_instance):
     """Test that experiment fetch trials from grand parent properly (adapters are muted)"""
-    experiment_name = 'supernaedo2.3.1'
-    root_name = 'supernaedo2'
-    leaf_names = ['supernaedo2.3.1']
+    experiment_name = "supernaedo2.3.1"
+    root_name = "supernaedo2"
+    leaf_names = ["supernaedo2.3.1"]
 
     experiment = ExperimentView(experiment_name)
     exp_node = build_trimmed_tree(experiment, root_name, leaf_names)
@@ -101,9 +101,9 @@ def test_parent_parent_fetch_trials(create_db_instance):
     experiment.connect_to_version_control_tree(exp_node)
 
     for node in exp_node.root:
-        node.item._experiment.refers['adapter'] = Adapter.build([])
+        node.item._experiment.refers["adapter"] = Adapter.build([])
 
-    query = {'status': 'completed'}
+    query = {"status": "completed"}
     assert len(exp_node.parent.parent.item.fetch_trials(query)) == 6
     assert len(exp_node.parent.item.fetch_trials(query)) == 4
     assert len(exp_node.item.fetch_trials(query)) == 2
@@ -116,9 +116,9 @@ def test_parent_parent_fetch_trials(create_db_instance):
 @pytest.mark.usefixtures("refers_id_substitution")
 def test_children_children_fetch_trials(create_db_instance):
     """Test that experiment fetch trials from grand children properly (adapters are muted)"""
-    experiment_name = 'supernaedo2'
-    root_name = 'supernaedo2'
-    leaf_names = ['supernaedo2.3.1']
+    experiment_name = "supernaedo2"
+    root_name = "supernaedo2"
+    leaf_names = ["supernaedo2.3.1"]
 
     experiment = ExperimentView(experiment_name)
     exp_node = build_trimmed_tree(experiment, root_name, leaf_names)
@@ -135,9 +135,9 @@ def test_children_children_fetch_trials(create_db_instance):
     experiment.connect_to_version_control_tree(exp_node)
 
     for node in exp_node.root:
-        node.item._experiment.refers['adapter'] = Adapter.build([])
+        node.item._experiment.refers["adapter"] = Adapter.build([])
 
-    query = {'status': 'completed'}
+    query = {"status": "completed"}
     assert len(exp_node.item.fetch_trials(query)) == 6
     assert len(exp_node.children[0].item.fetch_trials(query)) == 4
     assert len(exp_node.children[0].children[0].item.fetch_trials(query)) == 2
@@ -150,9 +150,9 @@ def test_children_children_fetch_trials(create_db_instance):
 @pytest.mark.usefixtures("refers_id_substitution")
 def test_deletion_adapter_forward(create_db_instance):
     """Test that all decoding_layer=gru pass to children"""
-    experiment_name = 'supernaedo2.1'
-    root_name = 'supernaedo2'
-    leaf_names = ['supernaedo2.1']
+    experiment_name = "supernaedo2.1"
+    root_name = "supernaedo2"
+    leaf_names = ["supernaedo2.1"]
 
     experiment = ExperimentView(experiment_name)
     exp_node = build_trimmed_tree(experiment, root_name, leaf_names)
@@ -167,11 +167,11 @@ def test_deletion_adapter_forward(create_db_instance):
 
     experiment.connect_to_version_control_tree(exp_node)
 
-    query = {'status': 'completed'}
+    query = {"status": "completed"}
     assert len(exp_node.item.fetch_trials(query)) == 1
     assert len(exp_node.parent.item.fetch_trials(query)) == 6
 
-    adapter = experiment.refers['adapter']
+    adapter = experiment.refers["adapter"]
     assert len(adapter.forward(exp_node.parent.item.fetch_trials(query))) == 1
     assert len(experiment.fetch_trials_tree(query)) == 1 + 1
 
@@ -181,9 +181,9 @@ def test_deletion_adapter_forward(create_db_instance):
 @pytest.mark.usefixtures("refers_id_substitution")
 def test_deletion_adapter_backward(create_db_instance):
     """Test that all decoding_layer are passed with gru to parent"""
-    experiment_name = 'supernaedo2'
-    root_name = 'supernaedo2'
-    leaf_names = ['supernaedo2.1']
+    experiment_name = "supernaedo2"
+    root_name = "supernaedo2"
+    leaf_names = ["supernaedo2.1"]
 
     experiment = ExperimentView(experiment_name)
     exp_node = build_trimmed_tree(experiment, root_name, leaf_names)
@@ -197,11 +197,11 @@ def test_deletion_adapter_backward(create_db_instance):
 
     experiment.connect_to_version_control_tree(exp_node)
 
-    query = {'status': 'completed'}
+    query = {"status": "completed"}
     assert len(exp_node.item.fetch_trials(query)) == 6
     assert len(exp_node.children[0].item.fetch_trials(query)) == 1
 
-    adapter = exp_node.children[0].item.refers['adapter']
+    adapter = exp_node.children[0].item.refers["adapter"]
     assert len(adapter.backward(exp_node.children[0].item.fetch_trials(query))) == 1
     assert len(experiment.fetch_trials_tree(query)) == 6 + 1
 
@@ -211,9 +211,9 @@ def test_deletion_adapter_backward(create_db_instance):
 @pytest.mark.usefixtures("refers_id_substitution")
 def test_renaming_forward(create_db_instance):
     """Test that all encoding_layer are renamed to encoding in children"""
-    experiment_name = 'supernaedo2.3'
-    root_name = 'supernaedo2'
-    leaf_names = ['supernaedo2.3']
+    experiment_name = "supernaedo2.3"
+    root_name = "supernaedo2"
+    leaf_names = ["supernaedo2.3"]
 
     experiment = ExperimentView(experiment_name)
     exp_node = build_trimmed_tree(experiment, root_name, leaf_names)
@@ -227,17 +227,19 @@ def test_renaming_forward(create_db_instance):
 
     experiment.connect_to_version_control_tree(exp_node)
 
-    query = {'status': 'completed'}
+    query = {"status": "completed"}
     parent_trials = exp_node.parent.item.fetch_trials(query)
     assert len(parent_trials) == 6
     assert len(exp_node.item.fetch_trials(query)) == 4
 
     assert all((trial._params[0].name == "/encoding_layer") for trial in parent_trials)
 
-    adapter = experiment.refers['adapter']
+    adapter = experiment.refers["adapter"]
     adapted_parent_trials = adapter.forward(parent_trials)
     assert len(adapted_parent_trials) == 6
-    assert all((trial._params[0].name == "/encoding") for trial in adapted_parent_trials)
+    assert all(
+        (trial._params[0].name == "/encoding") for trial in adapted_parent_trials
+    )
 
     assert len(experiment.fetch_trials_tree(query)) == 6 + 4
 
@@ -247,9 +249,9 @@ def test_renaming_forward(create_db_instance):
 @pytest.mark.usefixtures("refers_id_substitution")
 def test_renaming_backward(create_db_instance):
     """Test that all encoding are renamed to encoding_layer in parent"""
-    experiment_name = 'supernaedo2'
-    root_name = 'supernaedo2'
-    leaf_names = ['supernaedo2.3']
+    experiment_name = "supernaedo2"
+    root_name = "supernaedo2"
+    leaf_names = ["supernaedo2.3"]
 
     experiment = ExperimentView(experiment_name)
     exp_node = build_trimmed_tree(experiment, root_name, leaf_names)
@@ -263,17 +265,20 @@ def test_renaming_backward(create_db_instance):
 
     experiment.connect_to_version_control_tree(exp_node)
 
-    query = {'status': 'completed'}
+    query = {"status": "completed"}
     children_trials = exp_node.children[0].item.fetch_trials(query)
     assert len(children_trials) == 4
     assert len(exp_node.item.fetch_trials(query)) == 6
 
     assert all((trial._params[0].name == "/encoding") for trial in children_trials)
 
-    adapter = exp_node.children[0].item.refers['adapter']
+    adapter = exp_node.children[0].item.refers["adapter"]
     adapted_children_trials = adapter.backward(children_trials)
     assert len(adapted_children_trials) == 4
-    assert all((trial._params[0].name == "/encoding_layer") for trial in adapted_children_trials)
+    assert all(
+        (trial._params[0].name == "/encoding_layer")
+        for trial in adapted_children_trials
+    )
 
     assert len(experiment.fetch_trials_tree(query)) == 6 + 4
 
@@ -283,9 +288,9 @@ def test_renaming_backward(create_db_instance):
 @pytest.mark.usefixtures("refers_id_substitution")
 def test_prior_change_forward(create_db_instance):
     """Test that trials from parent only pass to children if valid in the new prior"""
-    experiment_name = 'supernaedo2.3.1'
-    root_name = 'supernaedo2.3'
-    leaf_names = ['supernaedo2.3.1']
+    experiment_name = "supernaedo2.3.1"
+    root_name = "supernaedo2.3"
+    leaf_names = ["supernaedo2.3.1"]
 
     experiment = ExperimentView(experiment_name)
     exp_node = build_trimmed_tree(experiment, root_name, leaf_names)
@@ -299,12 +304,12 @@ def test_prior_change_forward(create_db_instance):
 
     experiment.connect_to_version_control_tree(exp_node)
 
-    query = {'status': 'completed'}
+    query = {"status": "completed"}
     parent_trials = exp_node.parent.item.fetch_trials(query)
     assert len(parent_trials) == 4
     assert len(exp_node.item.fetch_trials(query)) == 2
 
-    adapter = experiment.refers['adapter']
+    adapter = experiment.refers["adapter"]
     adapted_parent_trials = adapter.forward(parent_trials)
     assert len(adapted_parent_trials) == 1
     assert len(experiment.fetch_trials_tree(query)) == 2 + 1
@@ -315,9 +320,9 @@ def test_prior_change_forward(create_db_instance):
 @pytest.mark.usefixtures("refers_id_substitution")
 def test_prior_change_backward(create_db_instance):
     """Test that all encoding are renamed to encoding_layer in parent"""
-    experiment_name = 'supernaedo2.3'
-    root_name = 'supernaedo2.3'
-    leaf_names = ['supernaedo2.3.1']
+    experiment_name = "supernaedo2.3"
+    root_name = "supernaedo2.3"
+    leaf_names = ["supernaedo2.3.1"]
 
     experiment = ExperimentView(experiment_name)
     exp_node = build_trimmed_tree(experiment, root_name, leaf_names)
@@ -331,12 +336,12 @@ def test_prior_change_backward(create_db_instance):
 
     experiment.connect_to_version_control_tree(exp_node)
 
-    query = {'status': 'completed'}
+    query = {"status": "completed"}
     children_trials = exp_node.children[0].item.fetch_trials(query)
     assert len(children_trials) == 2
     assert len(exp_node.item.fetch_trials(query)) == 4
 
-    adapter = exp_node.children[0].item.refers['adapter']
+    adapter = exp_node.children[0].item.refers["adapter"]
     adapted_children_trials = adapter.backward(children_trials)
     assert len(adapted_children_trials) == 1
 
@@ -348,9 +353,9 @@ def test_prior_change_backward(create_db_instance):
 @pytest.mark.usefixtures("refers_id_substitution")
 def test_code_change_noeffect_forward(create_db_instance):
     """Test that all trials pass to children when code change type is 'noeffect'"""
-    experiment_name = 'supernaedo2.3.1.1'
-    root_name = 'supernaedo2.3.1'
-    leaf_names = ['supernaedo2.3.1.1']
+    experiment_name = "supernaedo2.3.1.1"
+    root_name = "supernaedo2.3.1"
+    leaf_names = ["supernaedo2.3.1.1"]
 
     experiment = ExperimentView(experiment_name)
     exp_node = build_trimmed_tree(experiment, root_name, leaf_names)
@@ -364,12 +369,12 @@ def test_code_change_noeffect_forward(create_db_instance):
 
     experiment.connect_to_version_control_tree(exp_node)
 
-    query = {'status': 'completed'}
+    query = {"status": "completed"}
     parent_trials = exp_node.parent.item.fetch_trials(query)
     assert len(parent_trials) == 2
     assert len(exp_node.item.fetch_trials(query)) == 1
 
-    adapter = experiment.refers['adapter']
+    adapter = experiment.refers["adapter"]
     assert adapter.adapters[0].change_type == CodeChange.NOEFFECT
     adapted_parent_trials = adapter.forward(parent_trials)
     assert len(adapted_parent_trials) == 2
@@ -381,9 +386,9 @@ def test_code_change_noeffect_forward(create_db_instance):
 @pytest.mark.usefixtures("refers_id_substitution")
 def test_code_change_noeffect_backward(create_db_instance):
     """Test that all trials pass to parent when code change type is 'noeffect'"""
-    experiment_name = 'supernaedo2.3.1'
-    root_name = 'supernaedo2.3.1'
-    leaf_names = ['supernaedo2.3.1.1']
+    experiment_name = "supernaedo2.3.1"
+    root_name = "supernaedo2.3.1"
+    leaf_names = ["supernaedo2.3.1.1"]
 
     experiment = ExperimentView(experiment_name)
     exp_node = build_trimmed_tree(experiment, root_name, leaf_names)
@@ -397,12 +402,12 @@ def test_code_change_noeffect_backward(create_db_instance):
 
     experiment.connect_to_version_control_tree(exp_node)
 
-    query = {'status': 'completed'}
+    query = {"status": "completed"}
     children_trials = exp_node.children[0].item.fetch_trials(query)
     assert len(children_trials) == 1
     assert len(exp_node.item.fetch_trials(query)) == 2
 
-    adapter = exp_node.children[0].item.refers['adapter']
+    adapter = exp_node.children[0].item.refers["adapter"]
     assert adapter.adapters[0].change_type == CodeChange.NOEFFECT
     adapted_children_trials = adapter.backward(children_trials)
     assert len(adapted_children_trials) == 1
@@ -415,9 +420,9 @@ def test_code_change_noeffect_backward(create_db_instance):
 @pytest.mark.usefixtures("refers_id_substitution")
 def test_code_change_unsure_forward(create_db_instance):
     """Test that all trials pass to children when code change type is 'unsure'"""
-    experiment_name = 'supernaedo2.3.1.2'
-    root_name = 'supernaedo2.3.1'
-    leaf_names = ['supernaedo2.3.1.2']
+    experiment_name = "supernaedo2.3.1.2"
+    root_name = "supernaedo2.3.1"
+    leaf_names = ["supernaedo2.3.1.2"]
 
     experiment = ExperimentView(experiment_name)
     exp_node = build_trimmed_tree(experiment, root_name, leaf_names)
@@ -431,12 +436,12 @@ def test_code_change_unsure_forward(create_db_instance):
 
     experiment.connect_to_version_control_tree(exp_node)
 
-    query = {'status': 'completed'}
+    query = {"status": "completed"}
     parent_trials = exp_node.parent.item.fetch_trials(query)
     assert len(parent_trials) == 2
     assert len(exp_node.item.fetch_trials(query)) == 1
 
-    adapter = experiment.refers['adapter']
+    adapter = experiment.refers["adapter"]
     assert adapter.adapters[0].change_type == CodeChange.UNSURE
     adapted_parent_trials = adapter.forward(parent_trials)
     assert len(adapted_parent_trials) == 2
@@ -448,9 +453,9 @@ def test_code_change_unsure_forward(create_db_instance):
 @pytest.mark.usefixtures("refers_id_substitution")
 def test_code_change_unsure_backward(create_db_instance):
     """Test that no trials pass to parent when code change type is 'unsure'"""
-    experiment_name = 'supernaedo2.3.1'
-    root_name = 'supernaedo2.3.1'
-    leaf_names = ['supernaedo2.3.1.2']
+    experiment_name = "supernaedo2.3.1"
+    root_name = "supernaedo2.3.1"
+    leaf_names = ["supernaedo2.3.1.2"]
 
     experiment = ExperimentView(experiment_name)
     exp_node = build_trimmed_tree(experiment, root_name, leaf_names)
@@ -464,12 +469,12 @@ def test_code_change_unsure_backward(create_db_instance):
 
     experiment.connect_to_version_control_tree(exp_node)
 
-    query = {'status': 'completed'}
+    query = {"status": "completed"}
     children_trials = exp_node.children[0].item.fetch_trials(query)
     assert len(children_trials) == 1
     assert len(exp_node.item.fetch_trials(query)) == 2
 
-    adapter = exp_node.children[0].item.refers['adapter']
+    adapter = exp_node.children[0].item.refers["adapter"]
     assert adapter.adapters[0].change_type == CodeChange.UNSURE
     adapted_children_trials = adapter.backward(children_trials)
     assert len(adapted_children_trials) == 0
@@ -482,9 +487,9 @@ def test_code_change_unsure_backward(create_db_instance):
 @pytest.mark.usefixtures("refers_id_substitution")
 def test_code_change_break_forward(create_db_instance):
     """Test that no trials pass to children when code change type is 'break'"""
-    experiment_name = 'supernaedo2.3.1.3'
-    root_name = 'supernaedo2.3.1'
-    leaf_names = ['supernaedo2.3.1.3']
+    experiment_name = "supernaedo2.3.1.3"
+    root_name = "supernaedo2.3.1"
+    leaf_names = ["supernaedo2.3.1.3"]
 
     experiment = ExperimentView(experiment_name)
     exp_node = build_trimmed_tree(experiment, root_name, leaf_names)
@@ -498,12 +503,12 @@ def test_code_change_break_forward(create_db_instance):
 
     experiment.connect_to_version_control_tree(exp_node)
 
-    query = {'status': 'completed'}
+    query = {"status": "completed"}
     parent_trials = exp_node.parent.item.fetch_trials(query)
     assert len(parent_trials) == 2
     assert len(exp_node.item.fetch_trials(query)) == 1
 
-    adapter = experiment.refers['adapter']
+    adapter = experiment.refers["adapter"]
     assert adapter.adapters[0].change_type == CodeChange.BREAK
     adapted_parent_trials = adapter.forward(parent_trials)
     assert len(adapted_parent_trials) == 0
@@ -515,9 +520,9 @@ def test_code_change_break_forward(create_db_instance):
 @pytest.mark.usefixtures("refers_id_substitution")
 def test_code_change_break_backward(create_db_instance):
     """Test that no trials pass to parent when code change type is 'break'"""
-    experiment_name = 'supernaedo2.3.1'
-    root_name = 'supernaedo2.3.1'
-    leaf_names = ['supernaedo2.3.1.3']
+    experiment_name = "supernaedo2.3.1"
+    root_name = "supernaedo2.3.1"
+    leaf_names = ["supernaedo2.3.1.3"]
 
     experiment = ExperimentView(experiment_name)
     exp_node = build_trimmed_tree(experiment, root_name, leaf_names)
@@ -531,12 +536,12 @@ def test_code_change_break_backward(create_db_instance):
 
     experiment.connect_to_version_control_tree(exp_node)
 
-    query = {'status': 'completed'}
+    query = {"status": "completed"}
     children_trials = exp_node.children[0].item.fetch_trials(query)
     assert len(children_trials) == 1
     assert len(exp_node.item.fetch_trials(query)) == 2
 
-    adapter = exp_node.children[0].item.refers['adapter']
+    adapter = exp_node.children[0].item.refers["adapter"]
     assert adapter.adapters[0].change_type == CodeChange.BREAK
     adapted_children_trials = adapter.backward(children_trials)
     assert len(adapted_children_trials) == 0
@@ -549,9 +554,9 @@ def test_code_change_break_backward(create_db_instance):
 @pytest.mark.usefixtures("refers_id_substitution")
 def test_algo_change_forward(create_db_instance):
     """Test that all trials pass to children when algorithm is changed"""
-    experiment_name = 'supernaedo2.2.1'
-    root_name = 'supernaedo2.2'
-    leaf_names = ['supernaedo2.2.1']
+    experiment_name = "supernaedo2.2.1"
+    root_name = "supernaedo2.2"
+    leaf_names = ["supernaedo2.2.1"]
 
     experiment = ExperimentView(experiment_name)
     exp_node = build_trimmed_tree(experiment, root_name, leaf_names)
@@ -565,12 +570,12 @@ def test_algo_change_forward(create_db_instance):
 
     experiment.connect_to_version_control_tree(exp_node)
 
-    query = {'status': 'completed'}
+    query = {"status": "completed"}
     parent_trials = exp_node.parent.item.fetch_trials(query)
     assert len(parent_trials) == 1
     assert len(exp_node.item.fetch_trials(query)) == 1
 
-    adapter = experiment.refers['adapter']
+    adapter = experiment.refers["adapter"]
     adapted_parent_trials = adapter.forward(parent_trials)
     assert len(adapted_parent_trials) == 1
     assert len(experiment.fetch_trials_tree(query)) == 1 + 1
@@ -581,9 +586,9 @@ def test_algo_change_forward(create_db_instance):
 @pytest.mark.usefixtures("refers_id_substitution")
 def test_algo_change_backward(create_db_instance):
     """Test that all trials pass to parent when algorithm is changed"""
-    experiment_name = 'supernaedo2.2'
-    root_name = 'supernaedo2.2'
-    leaf_names = ['supernaedo2.2.1']
+    experiment_name = "supernaedo2.2"
+    root_name = "supernaedo2.2"
+    leaf_names = ["supernaedo2.2.1"]
 
     experiment = ExperimentView(experiment_name)
     exp_node = build_trimmed_tree(experiment, root_name, leaf_names)
@@ -597,12 +602,12 @@ def test_algo_change_backward(create_db_instance):
 
     experiment.connect_to_version_control_tree(exp_node)
 
-    query = {'status': 'completed'}
+    query = {"status": "completed"}
     children_trials = exp_node.children[0].item.fetch_trials(query)
     assert len(children_trials) == 1
     assert len(exp_node.item.fetch_trials(query)) == 1
 
-    adapter = exp_node.children[0].item.refers['adapter']
+    adapter = exp_node.children[0].item.refers["adapter"]
     adapted_children_trials = adapter.backward(children_trials)
     assert len(adapted_children_trials) == 1
 
@@ -614,7 +619,7 @@ def test_algo_change_backward(create_db_instance):
 @pytest.mark.usefixtures("refers_id_substitution")
 def test_full_backward(create_db_instance):
     """Test that trials are adapted properly up to root"""
-    experiment_name = 'supernaedo2'
+    experiment_name = "supernaedo2"
     root_name = None
     leaf_names = []
 
@@ -622,14 +627,14 @@ def test_full_backward(create_db_instance):
     exp_node = build_trimmed_tree(experiment, root_name, leaf_names)
 
     assert exp_node.item.name == experiment_name
-    assert exp_node.children[0].item.name == 'supernaedo2.1'
-    assert exp_node.children[1].item.name == 'supernaedo2.2'
-    assert exp_node.children[2].item.name == 'supernaedo2.3'
-    assert exp_node.children[1].children[0].item.name == 'supernaedo2.2.1'
-    assert exp_node.children[2].children[0].item.name == 'supernaedo2.3.1'
-    assert exp_node.children[2].children[0].children[0].item.name == 'supernaedo2.3.1.1'
-    assert exp_node.children[2].children[0].children[1].item.name == 'supernaedo2.3.1.2'
-    assert exp_node.children[2].children[0].children[2].item.name == 'supernaedo2.3.1.3'
+    assert exp_node.children[0].item.name == "supernaedo2.1"
+    assert exp_node.children[1].item.name == "supernaedo2.2"
+    assert exp_node.children[2].item.name == "supernaedo2.3"
+    assert exp_node.children[1].children[0].item.name == "supernaedo2.2.1"
+    assert exp_node.children[2].children[0].item.name == "supernaedo2.3.1"
+    assert exp_node.children[2].children[0].children[0].item.name == "supernaedo2.3.1.1"
+    assert exp_node.children[2].children[0].children[1].item.name == "supernaedo2.3.1.2"
+    assert exp_node.children[2].children[0].children[2].item.name == "supernaedo2.3.1.3"
     # 2
     # |    \      \
     # 2.1  2.2    2.3
@@ -641,16 +646,22 @@ def test_full_backward(create_db_instance):
 
     experiment.connect_to_version_control_tree(exp_node)
 
-    query = {'status': 'completed'}
+    query = {"status": "completed"}
     assert len(exp_node.item.fetch_trials(query)) == 6
     assert len(exp_node.children[0].item.fetch_trials(query)) == 1
     assert len(exp_node.children[1].item.fetch_trials(query)) == 1
     assert len(exp_node.children[2].item.fetch_trials(query)) == 4
     assert len(exp_node.children[1].children[0].item.fetch_trials(query)) == 1
     assert len(exp_node.children[2].children[0].item.fetch_trials(query)) == 2
-    assert len(exp_node.children[2].children[0].children[0].item.fetch_trials(query)) == 1
-    assert len(exp_node.children[2].children[0].children[1].item.fetch_trials(query)) == 1
-    assert len(exp_node.children[2].children[0].children[2].item.fetch_trials(query)) == 1
+    assert (
+        len(exp_node.children[2].children[0].children[0].item.fetch_trials(query)) == 1
+    )
+    assert (
+        len(exp_node.children[2].children[0].children[1].item.fetch_trials(query)) == 1
+    )
+    assert (
+        len(exp_node.children[2].children[0].children[2].item.fetch_trials(query)) == 1
+    )
 
     assert len(experiment.fetch_trials_tree(query)) == 15
 
@@ -660,7 +671,7 @@ def test_full_backward(create_db_instance):
 @pytest.mark.usefixtures("refers_id_substitution")
 def test_full_forward(create_db_instance):
     """Test that trials are adapted properly down to leaf"""
-    experiment_name = 'supernaedo2.3.1.1'
+    experiment_name = "supernaedo2.3.1.1"
     root_name = None
     leaf_names = []
 
@@ -668,9 +679,9 @@ def test_full_forward(create_db_instance):
     exp_node = build_trimmed_tree(experiment, root_name, leaf_names)
 
     assert exp_node.item.name == experiment_name
-    assert exp_node.parent.item.name == 'supernaedo2.3.1'
-    assert exp_node.parent.parent.item.name == 'supernaedo2.3'
-    assert exp_node.parent.parent.parent.item.name == 'supernaedo2'
+    assert exp_node.parent.item.name == "supernaedo2.3.1"
+    assert exp_node.parent.parent.item.name == "supernaedo2.3"
+    assert exp_node.parent.parent.parent.item.name == "supernaedo2"
     # 2
     # |
     # 2.3
@@ -682,7 +693,7 @@ def test_full_forward(create_db_instance):
 
     experiment.connect_to_version_control_tree(exp_node)
 
-    query = {'status': 'completed'}
+    query = {"status": "completed"}
     assert len(exp_node.item.fetch_trials(query)) == 1
     assert len(exp_node.parent.item.fetch_trials(query)) == 2
     assert len(exp_node.parent.parent.item.fetch_trials(query)) == 4
@@ -696,8 +707,8 @@ def test_full_forward(create_db_instance):
 @pytest.mark.usefixtures("refers_id_substitution")
 def test_full_forward_full_backward(create_db_instance):
     """Test that trials are adapted properly forward from parent and backward from leafs"""
-    experiment_name = 'supernaedo2.3'
-    root_name = 'supernaedo2'
+    experiment_name = "supernaedo2.3"
+    root_name = "supernaedo2"
     leaf_names = []
 
     experiment = ExperimentView(experiment_name)
@@ -705,10 +716,10 @@ def test_full_forward_full_backward(create_db_instance):
 
     assert exp_node.item.name == experiment_name
     assert exp_node.parent.name == root_name
-    assert exp_node.children[0].item.name == 'supernaedo2.3.1'
-    assert exp_node.children[0].children[0].item.name == 'supernaedo2.3.1.1'
-    assert exp_node.children[0].children[1].item.name == 'supernaedo2.3.1.2'
-    assert exp_node.children[0].children[2].item.name == 'supernaedo2.3.1.3'
+    assert exp_node.children[0].item.name == "supernaedo2.3.1"
+    assert exp_node.children[0].children[0].item.name == "supernaedo2.3.1.1"
+    assert exp_node.children[0].children[1].item.name == "supernaedo2.3.1.2"
+    assert exp_node.children[0].children[2].item.name == "supernaedo2.3.1.3"
     # 2
     # |
     # 2.3
@@ -720,7 +731,7 @@ def test_full_forward_full_backward(create_db_instance):
 
     experiment.connect_to_version_control_tree(exp_node)
 
-    query = {'status': 'completed'}
+    query = {"status": "completed"}
     assert len(exp_node.parent.item.fetch_trials(query)) == 6
     assert len(exp_node.item.fetch_trials(query)) == 4
     assert len(exp_node.children[0].item.fetch_trials(query)) == 2
