@@ -14,19 +14,23 @@ from orion.core.io.space_builder import DimensionBuilder
 @pytest.fixture
 def new_cat_dimension_conflict(old_config, new_config):
     """Generate a new dimension conflict with categorical prior for new experiment configuration"""
-    name = 'new-cat'
+    name = "new-cat"
     prior = 'choices(["hello", 2])'
     dimension = DimensionBuilder().build(name, prior)
     return evc.conflicts.NewDimensionConflict(old_config, new_config, dimension, prior)
 
 
 @pytest.fixture
-def missing_conflict_with_identical_prior(old_config, new_config, new_dimension_conflict):
+def missing_conflict_with_identical_prior(
+    old_config, new_config, new_dimension_conflict
+):
     """Generate a missing dimension conflict which have the same prior as the new dim conflict"""
-    name = 'missing-idem'
+    name = "missing-idem"
     prior = new_dimension_conflict.prior
     dimension = DimensionBuilder().build(name, prior)
-    return evc.conflicts.MissingDimensionConflict(old_config, new_config, dimension, prior)
+    return evc.conflicts.MissingDimensionConflict(
+        old_config, new_config, dimension, prior
+    )
 
 
 @pytest.fixture
@@ -34,19 +38,29 @@ def missing_cat_dimension_conflict(old_config, new_config):
     """Generate a missing dimension conflict with categorical prior for new experiment
     configuration
     """
-    name = 'missing-cat'
+    name = "missing-cat"
     prior = 'choices(["goodbye", 5])'
     dimension = DimensionBuilder().build(name, prior)
-    return evc.conflicts.MissingDimensionConflict(old_config, new_config, dimension, prior)
+    return evc.conflicts.MissingDimensionConflict(
+        old_config, new_config, dimension, prior
+    )
 
 
 @pytest.fixture
-def conflicts(new_dimension_conflict, new_cat_dimension_conflict,
-              changed_dimension_conflict,
-              missing_dimension_conflict, missing_cat_dimension_conflict,
-              missing_conflict_with_identical_prior,
-              algorithm_conflict, code_conflict, cli_conflict, config_conflict,
-              experiment_name_conflict):
+def conflicts(
+    new_dimension_conflict,
+    new_cat_dimension_conflict,
+    changed_dimension_conflict,
+    missing_dimension_conflict,
+    missing_cat_dimension_conflict,
+    missing_conflict_with_identical_prior,
+    algorithm_conflict,
+    orion_version_conflict,
+    code_conflict,
+    cli_conflict,
+    config_conflict,
+    experiment_name_conflict,
+):
     """Create a container for conflicts with one of each types for testing purposes"""
     conflicts = evc.conflicts.Conflicts()
     conflicts.register(new_dimension_conflict)
@@ -56,6 +70,7 @@ def conflicts(new_dimension_conflict, new_cat_dimension_conflict,
     conflicts.register(missing_cat_dimension_conflict)
     conflicts.register(missing_conflict_with_identical_prior)
     conflicts.register(algorithm_conflict)
+    conflicts.register(orion_version_conflict)
     conflicts.register(code_conflict)
     conflicts.register(config_conflict)
     conflicts.register(cli_conflict)
@@ -66,7 +81,7 @@ def conflicts(new_dimension_conflict, new_cat_dimension_conflict,
 @pytest.fixture
 def branch_builder(conflicts):
     """Generate the experiment branch builder"""
-    return ExperimentBranchBuilder(conflicts, {'manual_resolution': True})
+    return ExperimentBranchBuilder(conflicts, {"manual_resolution": True})
 
 
 @pytest.fixture
@@ -99,7 +114,7 @@ class TestCommands(object):
         assert len(conflicts.get_resolved()) == 1
         branch_solver_prompt.do_add("new")
         out, err = capsys.readouterr()
-        assert "Dimension name \'new\' not found in conflicts" in out
+        assert "Dimension name 'new' not found in conflicts" in out
         assert len(conflicts.get_resolved()) == 1
 
     def test_add_dim_with_default(self, conflicts, branch_solver_prompt):
@@ -128,7 +143,7 @@ class TestCommands(object):
         assert len(conflicts.get_resolved()) == 0
         branch_solver_prompt.do_add("new_cat --default-value='hello'")
         assert len(conflicts.get_resolved()) == 1
-        assert conflicts.get_resolved()[0].resolution.default_value == 'hello'
+        assert conflicts.get_resolved()[0].resolution.default_value == "hello"
 
         conflicts.revert(conflicts.get_resolved()[0].resolution)
         assert len(conflicts.get_resolved()) == 0
@@ -136,7 +151,9 @@ class TestCommands(object):
         assert len(conflicts.get_resolved()) == 1
         assert conflicts.get_resolved()[0].resolution.default_value == 2
 
-    def test_add_dim_with_cat_bad_default(self, capsys, conflicts, branch_solver_prompt):
+    def test_add_dim_with_cat_bad_default(
+        self, capsys, conflicts, branch_solver_prompt
+    ):
         """Verify that error message is given for default value of invalid category"""
         assert len(conflicts.get_resolved()) == 0
         branch_solver_prompt.do_add("new_cat --default-value='bad'")
@@ -149,7 +166,9 @@ class TestCommands(object):
         assert len(conflicts.get_resolved()) == 0
         branch_solver_prompt.do_add("new")
         assert len(conflicts.get_resolved()) == 1
-        branch_solver_prompt.do_reset("'{}'".format(str(conflicts.get_resolved()[0].resolution)))
+        branch_solver_prompt.do_reset(
+            "'{}'".format(str(conflicts.get_resolved()[0].resolution))
+        )
         assert len(conflicts.get_resolved()) == 0
 
     def test_change_dim(self, conflicts, branch_solver_prompt):
@@ -165,7 +184,7 @@ class TestCommands(object):
         assert len(conflicts.get_resolved()) == 1
         branch_solver_prompt.do_add("changed")
         out, err = capsys.readouterr()
-        assert "Dimension name \'changed\' not found in conflicts" in out
+        assert "Dimension name 'changed' not found in conflicts" in out
         assert len(conflicts.get_resolved()) == 1
 
     def test_reset_change(self, conflicts, branch_solver_prompt):
@@ -173,7 +192,9 @@ class TestCommands(object):
         assert len(conflicts.get_resolved()) == 0
         branch_solver_prompt.do_add("changed")
         assert len(conflicts.get_resolved()) == 1
-        branch_solver_prompt.do_reset("'{}'".format(str(conflicts.get_resolved()[0].resolution)))
+        branch_solver_prompt.do_reset(
+            "'{}'".format(str(conflicts.get_resolved()[0].resolution))
+        )
         assert len(conflicts.get_resolved()) == 0
 
     def test_remove_dim(self, conflicts, branch_solver_prompt):
@@ -197,7 +218,7 @@ class TestCommands(object):
         assert len(conflicts.get_resolved()) == 1
         branch_solver_prompt.do_remove("missing")
         out, err = capsys.readouterr()
-        assert "Dimension name \'missing\' not found in conflicts" in out
+        assert "Dimension name 'missing' not found in conflicts" in out
         assert len(conflicts.get_resolved()) == 1
 
     def test_remove_dim_with_default(self, conflicts, branch_solver_prompt):
@@ -226,7 +247,7 @@ class TestCommands(object):
         assert len(conflicts.get_resolved()) == 0
         branch_solver_prompt.do_remove("missing_cat --default-value='goodbye'")
         assert len(conflicts.get_resolved()) == 1
-        assert conflicts.get_resolved()[0].resolution.default_value == 'goodbye'
+        assert conflicts.get_resolved()[0].resolution.default_value == "goodbye"
 
         conflicts.revert(conflicts.get_resolved()[0].resolution)
         assert len(conflicts.get_resolved()) == 0
@@ -234,7 +255,9 @@ class TestCommands(object):
         assert len(conflicts.get_resolved()) == 1
         assert conflicts.get_resolved()[0].resolution.default_value == 5
 
-    def test_remove_dim_with_cat_bad_default(self, capsys, conflicts, branch_solver_prompt):
+    def test_remove_dim_with_cat_bad_default(
+        self, capsys, conflicts, branch_solver_prompt
+    ):
         """Verify that error message is given for default value of invalid category"""
         assert len(conflicts.get_resolved()) == 0
         branch_solver_prompt.do_remove("missing_cat --default-value='bad'")
@@ -247,64 +270,70 @@ class TestCommands(object):
         assert len(conflicts.get_resolved()) == 0
         branch_solver_prompt.do_remove("missing")
         assert len(conflicts.get_resolved()) == 1
-        branch_solver_prompt.do_reset("'{}'".format(str(conflicts.get_resolved()[0].resolution)))
+        branch_solver_prompt.do_reset(
+            "'{}'".format(str(conflicts.get_resolved()[0].resolution))
+        )
         assert len(conflicts.get_resolved()) == 0
 
     def test_rename_dim(self, conflicts, branch_solver_prompt):
         """Verify that rename resolution is properly created"""
         assert len(conflicts.get_resolved()) == 0
-        assert len(conflicts.get()) == 11
+        assert len(conflicts.get()) == 12
         branch_solver_prompt.do_rename("missing_idem new")
         assert len(conflicts.get_resolved()) == 2
-        assert len(conflicts.get()) == 11
+        assert len(conflicts.get()) == 12
 
     def test_rename_and_change_dim(self, conflicts, branch_solver_prompt):
         """Verify that rename resolution is created and a new side-effect conflict added"""
         assert len(conflicts.get_resolved()) == 0
-        assert len(conflicts.get()) == 11
+        assert len(conflicts.get()) == 12
         branch_solver_prompt.do_rename("missing new")
         assert len(conflicts.get_resolved()) == 2
-        assert len(conflicts.get()) == 12
+        assert len(conflicts.get()) == 13
 
     def test_rename_bad_dim(self, capsys, conflicts, branch_solver_prompt):
         """Verify error messages when attempting invalid renamings"""
         assert len(conflicts.get_resolved()) == 0
-        assert len(conflicts.get()) == 11
+        assert len(conflicts.get()) == 12
         branch_solver_prompt.do_rename("new_cat new")
         out, err = capsys.readouterr()
-        assert "Dimension name \'new_cat\' not found in conflicts" in out
+        assert "Dimension name 'new_cat' not found in conflicts" in out
         assert len(conflicts.get_resolved()) == 0
-        assert len(conflicts.get()) == 11
+        assert len(conflicts.get()) == 12
 
         assert len(conflicts.get_resolved()) == 0
-        assert len(conflicts.get()) == 11
+        assert len(conflicts.get()) == 12
         branch_solver_prompt.do_rename("missing missing_cat")
         out, err = capsys.readouterr()
-        assert "Dimension name \'missing_cat\' not found in conflicts" in out
+        assert "Dimension name 'missing_cat' not found in conflicts" in out
         assert len(conflicts.get_resolved()) == 0
-        assert len(conflicts.get()) == 11
+        assert len(conflicts.get()) == 12
 
     def test_reset_rename_with_same_priors(self, conflicts, branch_solver_prompt):
         """Verify that rename resolution is reverted"""
         assert len(conflicts.get_resolved()) == 0
-        assert len(conflicts.get()) == 11
+        assert len(conflicts.get()) == 12
         branch_solver_prompt.do_rename("missing_idem new")
         assert len(conflicts.get_resolved()) == 2
-        assert len(conflicts.get()) == 11
-        branch_solver_prompt.do_reset("'{}'".format(str(conflicts.get_resolved()[0].resolution)))
+        assert len(conflicts.get()) == 12
+        branch_solver_prompt.do_reset(
+            "'{}'".format(str(conflicts.get_resolved()[0].resolution))
+        )
         assert len(conflicts.get_resolved()) == 0
-        assert len(conflicts.get()) == 11
+        assert len(conflicts.get()) == 12
 
     def test_reset_rename_with_different_priors(self, conflicts, branch_solver_prompt):
         """Verify that rename resolution is reverted and side-effect conflit is removed"""
         assert len(conflicts.get_resolved()) == 0
-        assert len(conflicts.get()) == 11
+        assert len(conflicts.get()) == 12
         branch_solver_prompt.do_rename("missing new")
         assert len(conflicts.get_resolved()) == 2
-        assert len(conflicts.get()) == 12
-        branch_solver_prompt.do_reset("'{}'".format(str(conflicts.get_resolved()[0].resolution)))
+        assert len(conflicts.get()) == 13
+        branch_solver_prompt.do_reset(
+            "'{}'".format(str(conflicts.get_resolved()[0].resolution))
+        )
         assert len(conflicts.get_resolved()) == 0
-        assert len(conflicts.get()) == 11
+        assert len(conflicts.get()) == 12
 
     def test_set_code_change_type(self, conflicts, branch_solver_prompt):
         """Verify that code change resolution is created"""
@@ -335,7 +364,9 @@ class TestCommands(object):
         assert len(conflicts.get_resolved()) == 0
         branch_solver_prompt.do_code("break")
         assert len(conflicts.get_resolved()) == 1
-        branch_solver_prompt.do_reset("'{}'".format(str(conflicts.get_resolved()[0].resolution)))
+        branch_solver_prompt.do_reset(
+            "'{}'".format(str(conflicts.get_resolved()[0].resolution))
+        )
         assert len(conflicts.get_resolved()) == 0
 
     def test_set_algo(self, conflicts, branch_solver_prompt):
@@ -359,7 +390,35 @@ class TestCommands(object):
         assert len(conflicts.get_resolved()) == 0
         branch_solver_prompt.do_algo("")
         assert len(conflicts.get_resolved()) == 1
-        branch_solver_prompt.do_reset("' {}'".format(str(conflicts.get_resolved()[0].resolution)))
+        branch_solver_prompt.do_reset(
+            "' {}'".format(str(conflicts.get_resolved()[0].resolution))
+        )
+        assert len(conflicts.get_resolved()) == 0
+
+    def test_set_orion_version(self, conflicts, branch_solver_prompt):
+        """Verify that orion version resolution is created"""
+        assert len(conflicts.get_resolved()) == 0
+        branch_solver_prompt.do_orion_version("")
+        assert len(conflicts.get_resolved()) == 1
+
+    def test_set_orion_version_twice(self, capsys, conflicts, branch_solver_prompt):
+        """Verify that error message is given trying to solve twice the same conflict"""
+        assert len(conflicts.get_resolved()) == 0
+        branch_solver_prompt.do_orion_version("")
+        assert len(conflicts.get_resolved()) == 1
+        branch_solver_prompt.do_orion_version("")
+        out, err = capsys.readouterr()
+        assert "No orion version conflict to solve" in out
+        assert len(conflicts.get_resolved()) == 1
+
+    def test_reset_orion_version(self, conflicts, branch_solver_prompt):
+        """Verify that orion version resolution is reverted"""
+        assert len(conflicts.get_resolved()) == 0
+        branch_solver_prompt.do_orion_version("")
+        assert len(conflicts.get_resolved()) == 1
+        branch_solver_prompt.do_reset(
+            "' {}'".format(str(conflicts.get_resolved()[0].resolution))
+        )
         assert len(conflicts.get_resolved()) == 0
 
     def test_set_config_change_type(self, conflicts, branch_solver_prompt):
@@ -376,7 +435,9 @@ class TestCommands(object):
         assert "invalid choice: 'bad'" in err
         assert len(conflicts.get_resolved()) == 0
 
-    def test_set_config_change_type_twice(self, capsys, conflicts, branch_solver_prompt):
+    def test_set_config_change_type_twice(
+        self, capsys, conflicts, branch_solver_prompt
+    ):
         """Verify that error message is given trying to solve twice the same conflict"""
         assert len(conflicts.get_resolved()) == 0
         branch_solver_prompt.do_config("break")
@@ -391,7 +452,9 @@ class TestCommands(object):
         assert len(conflicts.get_resolved()) == 0
         branch_solver_prompt.do_config("break")
         assert len(conflicts.get_resolved()) == 1
-        branch_solver_prompt.do_reset("'{}'".format(str(conflicts.get_resolved()[0].resolution)))
+        branch_solver_prompt.do_reset(
+            "'{}'".format(str(conflicts.get_resolved()[0].resolution))
+        )
         assert len(conflicts.get_resolved()) == 0
 
     def test_set_commandline_change_type(self, conflicts, branch_solver_prompt):
@@ -400,7 +463,9 @@ class TestCommands(object):
         branch_solver_prompt.do_commandline("break")
         assert len(conflicts.get_resolved()) == 1
 
-    def test_set_commandline_change_bad_type(self, capsys, conflicts, branch_solver_prompt):
+    def test_set_commandline_change_bad_type(
+        self, capsys, conflicts, branch_solver_prompt
+    ):
         """Verify error message when attempting cli resolution with bad type"""
         assert len(conflicts.get_resolved()) == 0
         branch_solver_prompt.do_commandline("bad")
@@ -408,7 +473,9 @@ class TestCommands(object):
         assert "invalid choice: 'bad'" in err
         assert len(conflicts.get_resolved()) == 0
 
-    def test_set_commandline_change_type_twice(self, capsys, conflicts, branch_solver_prompt):
+    def test_set_commandline_change_type_twice(
+        self, capsys, conflicts, branch_solver_prompt
+    ):
         """Verify that error message is given trying to solve twice the same conflict"""
         assert len(conflicts.get_resolved()) == 0
         branch_solver_prompt.do_commandline("break")
@@ -423,7 +490,9 @@ class TestCommands(object):
         assert len(conflicts.get_resolved()) == 0
         branch_solver_prompt.do_commandline("break")
         assert len(conflicts.get_resolved()) == 1
-        branch_solver_prompt.do_reset("'{}'".format(str(conflicts.get_resolved()[0].resolution)))
+        branch_solver_prompt.do_reset(
+            "'{}'".format(str(conflicts.get_resolved()[0].resolution))
+        )
         assert len(conflicts.get_resolved()) == 0
 
     def test_set_experiment_name(self, conflicts, branch_solver_prompt):
@@ -455,16 +524,18 @@ class TestCommands(object):
         assert len(conflicts.get_resolved()) == 0
         branch_solver_prompt.do_name("new-name")
         assert len(conflicts.get_resolved()) == 1
-        branch_solver_prompt.do_reset("'{}'".format(str(conflicts.get_resolved()[0].resolution)))
+        branch_solver_prompt.do_reset(
+            "'{}'".format(str(conflicts.get_resolved()[0].resolution))
+        )
         assert len(conflicts.get_resolved()) == 0
 
     def test_commit_wont_quit_if_not_solved(self, conflicts, branch_solver_prompt):
         """Verify that commit will not quit if some conflicts are not resolved"""
         assert len(conflicts.get_resolved()) == 0
-        assert len(conflicts.get()) == 11
+        assert len(conflicts.get()) == 12
         branch_solver_prompt.do_auto("")
-        assert len(conflicts.get()) == 11
-        assert len(conflicts.get_resolved()) == 10
+        assert len(conflicts.get()) == 12
+        assert len(conflicts.get_resolved()) == 11
 
         assert branch_solver_prompt.do_commit("") is False
 
@@ -478,18 +549,18 @@ class TestCommands(object):
     def test_auto(self, conflicts, branch_solver_prompt):
         """Verify that all conflicts which requires not input are automatically resolved"""
         assert len(conflicts.get_resolved()) == 0
-        assert len(conflicts.get()) == 11
+        assert len(conflicts.get()) == 12
         branch_solver_prompt.do_auto("")
-        assert len(conflicts.get()) == 11
-        assert len(conflicts.get_resolved()) == 10
+        assert len(conflicts.get()) == 12
+        assert len(conflicts.get_resolved()) == 11
 
     def test_reset_many(self, conflicts, branch_solver_prompt):
         """Verify that all resolutions are reverted"""
         assert len(conflicts.get_resolved()) == 0
-        assert len(conflicts.get()) == 11
+        assert len(conflicts.get()) == 12
         branch_solver_prompt.do_auto("")
-        assert len(conflicts.get()) == 11
-        assert len(conflicts.get_resolved()) == 10
+        assert len(conflicts.get()) == 12
+        assert len(conflicts.get_resolved()) == 11
 
         reset_strings = []
         for resolution in conflicts.get_resolutions():
